
global path "C:\WBG\github\reppackage_131\v2"

/* 1a. path name where EHCVM dataset is stored at*/
global ehcvm_input "${path}/data/EHCVM (by INSD)"

/* 1b. path name where LSMS dataset is stored at*/
global lsms_input "${path}/data/LSMS 2014"


/* 2. path name where all the do files are saved, and where all the intermediate files and the final Tables will be saved*/
global reproduce_files "${path}/do-files"
global outputs "${path}/outputs"
global intermediate "${path}/data/intermediate"
sysdir set PLUS "${reproduce_files}/ado"
set varabbrev on

/*installing required Stata packages*/
*ssc install outreg2
*ssc install oaxaca
*ssc install unique

/***********************Cleaning the Files***********************/

/*STEP 1: THIS DO FILE CLEANS THE EHCVM FILES AND THEN SAVES THEM IN THE FOLDER SPECIFIED IN THE REPRODUCE_FILES PATHNAME*/
do "$reproduce_files\Step 1 - Cleaning EHCVM.do"


/*STEP 2: THIS DO FILE CLEANS THE LSMS FILES AND THEN SAVES THEM IN THE FOLDER SPECIFIED IN THE REPRODUCE_FILES PATHNAME*/
do "$reproduce_files\Step 2 - Cleaning LSMS.do"


/***************************Running the Regressions***************************/

/*STEP 3a: RUNS THE REGRESSIONS COMPARING THE RAW GENDER GAP IN EHCVM, AND COMPARES THE GENDER GAP
BETWEEN LSMS AND EHCVM

ADDITIONALLY, IT CREATES A NUMBER OF SUMMARTY STATS TABLES:
  1. EXCEL FILE TABLE 1A.XLS, WHICH IS THE TABLE 1A IN THE PAPER. NOTE: THE VALUES OF OVERALL LFP AND PAID LFP ARE ALREADY CONVERTED TO PERCENTAGE POINTS USING MFX, BUT THE VALUES FOR BUSINESS REVENUES, HARVEST VALUE AND CROP SOLD VALUE NEED TO BE CONVERTED TO PERCENTS USING "EXP(COEFFICIENT) - 1" TRANSFORMATION. SINCE THE WAGE GAP PROPORTION IS FOUND USING THE FORMULA "COEFFICENT ON FEMALE DUMMY / CONSTANT * 100"
		Table 1A is saved in the pathway specified in $regression (line 26 above)
	
  2. TABLE 2 - THE WAGE GAP COEFFICIENTS AND THEIR T-VALUES FOR THE YEAR 2014, AND THOSE OF 2018. THE PVALUE OF THE EQUALITY OF COEFFICIENTS BETWEEN 2014 AND 2018 ARE ALSO CALCULATED AND REPORTED. 
  
  3. APPENDIX TABLE 1 - THIS SHOWS THE URBANICITY OF PROVINCES IN 2014 AND 2018. 
  
  4. FIGURE 1 - THE NUMBERS USED TO DRAW THE VENN DIAGRAM ARE CALCULATED AND STORED IN THE EXCEL FILE 'FIGURE 1.' THE USER CAN DRAW THE VENN DIAGRAM IN WORD.
*/

do "$reproduce_files\Step 3 - Figure 1 Tables 1A 2 and App Table 1.do"
 


/*STEP 4: RUNS THE KITAGAWA-OAXACA-BLINDER DECOMPOSITION OF EHCVM AND FINDS THE SUMMARY STATISTICS

THIS DO FILE CREATES THE FOLLOWING:
   A. TABLE 1B - THE SUMMARY STATISTICS (SEPARATE FILES CREATED FOR PAID ONLY LFP, OVERALL LFP, WAGES, BUSINESS REVENUES, HARVEST VALUE, CROP SALES. IN EACH EXCEL FILE, THE FIRST THREE COLUMN IS FOR THE FULL POPULATION, THEN NEXT THREE (4-6) IS FOR THE MALE POPULATION, AND THEN THE NEXT THREE (7-9) IS FOR THE FEMALE POPULATION. THE NEXT THREE (10-12) IS FOR ALL 15-29 POPULATION, THEN (13-15) IS FOR THE MALE 15-29 YEAR OLDS, AND THEN (COLUMNS 16-18) IS FOR THE FEMALES AGED 15-29. THE SUBSEQUENT COLUMNS (19-21) IS FOR ALL POPULATION AGED 30-64, THEN (COLUMNS 22-24) IS FOR MALES AGED 30-64, AND THEN (COLUMNS 25-27) IS FOR FEMALES AGED 30-64)
   B. TABLE 3 - PAID LFP AND OVERALL LFP DECOMPOSITIONS
   C. TABLE 4 - WAGE DECOMPOSITION
   D. TABLE 5 - BUSINESS REVENUES DECOMPOSITION
   E. TABLE 6 - HARVEST VALUE AND CROP SALES DECOMPOSITIONS
   F. APPENDIX TABLE 2 - OVERALL LFP DECOMPOSITION BY AGE
   G. APPENDIX TABLE 3 - OVERALL LFP DECOMPOSITION BY URBAN/RURAL
   H. APPENDIX TABLE 4 - WAGE DECOMPOSITION BY AGE
   I. APPENDIX TABLE 5 - WAGE DECOMPOSITION BY URBAN/RURAL
   J. APPENDIX TABLE 6 - BUSINESS REVENUES DECOMPOSITION BY AGE
   K. APPENDIX TABLE 7 - BUSINESS REVENUES DECOMPOSITION BY URBAN/RURAL
   L. APPENDIX TABLE 8 - HARVEST VALUE DECOMPOSITION BY AGE
   M. APPENDIX TABLE 9 - CROP SALES DECOMPOSITION BY AGE

   
  
*/

do "$reproduce_files\Step 4 - KOB Regressions.do"

