/********************************************************
CLEANING THE EHCVM DATASET
********************************************************/

clear

use "$ehcvm_input/s00_me_BFA2018.dta", clear

keep hhid grappe menage vague interview__key interview__id s00q01 s00q02 s00q03 s00q04 s00q05
rename s00q01 region
rename s00q02 province
rename s00q03 municipality 
rename s00q04 urban
rename s00q05 village

save "$reproduce_files\EHCVM Household data.dta", replace

keep hhid interview__key interview__id
merge 1:1 hhid using "$ehcvm_input\ehcvm_welfare_BFA2018.dta"
keep hhid interview__key interview__id hhweight hhsize
save "$reproduce_files\EHCVM hhweight.dta", replace


/************HOUSEHOLD ROSTER****************/

use "$ehcvm_input\s01_me_BFA2018.dta", clear

label define yesno 1 "yes" 0 "no"
label define gender 1 "male" 0 "female"
label define relation 1 "Head of Household" 2 "Partner/Spouse" 3 "Son, Daughter" 4 "Father, Mother" 5 "Grandson, Granddaughter" 6 "Grandparent" 7 "Brother, Sister" 8 "Other Relatives" 9 "Non-relative" 10 "House Help" 

label define maritalstatus 1 "Single" 2 "Married-monogamous" 3 "Married-polygamist" 4 "Common Law Union" 5 "Widow(er)" 6 "Divorced" 7 "Separated" 8 "NC"

label define religion 1 "Muslim" 2 "Christian" 3 "Animist" 4 "Other" 5 "Without Religion"

label define education 1 "None" 2 "Primary" 3 "Post-primary" 4 "Secondary" 5 "Post-secondary" 6 "DK"

label define industry 0 "unemployed" 1 "Agriculture" 2 "Mining" 3 "Industry/Electricity/Water" 4 "Construction" 5 "Trade" 6 "Transport" 7 "Restaurant/Hotel" 8 "Arts/Entertainment" 9 "Services" 10 "DK"

label define profession 1 "Senior Manager" 2 "Middle Management" 3 "Skilled worker" 4 "unskilled (simple) worker" 5 "Laborer" 6 "Pattern" 7 "self-employed" 8 "Other" 9 "DK"

label variable s01q00a "HH Member ID"
rename s01q00a member_id
label variable s01q01 "Gender of the Person"
rename s01q01 gender
replace gender = 0 if gender ==2
label values gender gender

gen female=.
replace female=1 if gender==0
replace female=0 if gender==1

label variable s01q02 "Relation to the Head of HH"
rename s01q02 relation
label values relation relation

label variable s01q03c "Year of Birth"
rename s01q03c yearborn
label variable s01q04a "Age in years"
rename s01q04a age
replace age = 2018 - yearborn if age==.

label variable s01q07 "Marital Status of the person"
rename s01q07 maritalstatus
label values maritalstatus maritalstatus


forvalues i=0/5 {
	rename s01q09__`i' spouse`i'
	label variable spouse`i' "ID of spouse `i'
	}
	
label variable s01q10 "At what age were you first married"
rename s01q10 ageofmarriage
label variable s01q14 "Religion of person"
rename s01q14 religion	
label values religion religion

label variable s01q16 "Ethnicity"
rename s01q16 Ethnicity

label variable s01q25 "Education attainment of father of person"
rename s01q25 father_educ
label values father_educ education

label variable s01q26 "Industry of work of father"
rename s01q26 father_industry
label values father_industry industry

label variable s01q27 "Profession of Father"
rename s01q27 father_profession
label values father_profession profession

label variable s01q32 "Education attainment of mother"
rename s01q32 mother_educ
label values mother_educ education


label variable s01q33 "Industry of work of mother"
rename s01q33 mother_industry
label values mother_industry industry

label variable s01q34 "Profession of Mother"
rename s01q34 mother_profession
label values mother_profession profession

label variable s01q36 "own a cellphone (for age 10+ years)"
rename s01q36 cellphone
label variable s01q39__1 "Internet access on the phone"
rename s01q39__1 internet_phone
label variable s01q39__2 "Internet access in the office"
rename s01q39__2 internet_office
label variable s01q39__3 "Internet access in cybercafe"
rename s01q39__3 internet_cybercafe
label variable s01q39__4 "Internet access at home"
rename s01q39__4 internet_home
label variable s01q39__5 "Internet access at university"
rename s01q39__5 internet_university


drop s00q08 s00q27 s01q00b s01q03a s01q03b s01q04b s01q05 s01q06 s01q00c s01q08 s01q11 s01q12 s01q15- s01q24 s01q28- s01q31 s01q35 s01q37 s01q38


gen one=1
sort interview__id 
by interview__id: egen hh_size=sum(one)

/*dependency ratio*/
gen deps=0
replace deps=1 if age<15 | age>64 & age!=.
by interview__id: egen total_deps=sum(deps)

gen adt=0
replace adt=1 if age>=15 & age<=64
by interview__id: egen adults=sum(adt)
gen dep_ratio= total_deps/adults

drop deps adt
gen deps=0
replace deps=1 if age<=5 & relation==3
by interview__id: egen child0_5 =sum(deps)

drop deps
gen deps=0
replace deps=1 if age>5 & age<=10 & relation==3
by interview__id: egen child5_10 =sum(deps)
replace child5_10=0 if relation>=3
drop deps

gen deps=0
replace deps=1 if age>10 & age<15
by interview__id: egen child10_14 =sum(deps)
drop deps

merge m:1 interview__id using "$reproduce_files\EHCVM hhweight.dta"
drop _merge

merge m:1 interview__id using "$reproduce_files\EHCVM Household data.dta"
drop _merge

drop one

save "$reproduce_files/EHCVM Roster.dta", replace


/***************EDUCATION ATTAINMENT***************/

use "$ehcvm_input\s02_me_BFA2018.dta", clear

label define yesno 1 "yes" 0 "no"

label define whynoschool 1 "Too young" 2 "No school, too far away" 3 "family refused" 4 "preference for job" 5 "field work/pastoralism" 6 "housework" 7 "she is a girl" 8 "high tuition fees" 9 "lack of financial means" 10 "unsuitable studies" 11 "unnecessary studies" 12 "illness/infirmity" 13 "insecurity" 14 "others"

label define nonformal 1 "Koranic School" 2 "Professional Training" 3 "Literacy courses" 

label define higheduc 1 "Kindergarten" 2 "Primary" 3 "Secondary 1 - general" 4 "Secondary 1 - technical" 5 "Secondary 2 - general" 6 "Secondary 2 - technical" 7 "Post-secondary for BAC+2" 8 "Superieur"

label define field 1 "Sciences" 2 "Humanities" 3 "Administration" 4 "Engineering" 5 "Law and Legal Services" 6 "Economic Science" 7 "Other"

label define degree 0 "No" 1 "CEP" 2 "BEPC" 3 "CAP" 4 "BEP" 5 "BAC" 6 "DEUG/DUT/BTS" 7 "License" 8 "Mastery" 9 "Masters/DEA/DESS" 10 "PhD"


label variable s01q00a "HH Member ID"
rename s01q00a member_id

label variable s02q01__1 "Can you read French?"
rename s02q01__1 read_french
label variable s02q01__2 "Can you read local language"
rename s02q01__2 read_locallanguage
label variable s02q01__3 "Can you read other language"
rename s02q01__3 read_other
label variable s02q02__1 "Can you write French?"
rename s02q02__1 write_french
label variable s02q02__2 "Can you write local language"
rename s02q02__2 write_locallanguage
label variable s02q02__3 "Can you write other language"
rename s02q02__3 write_other
label variable s02q03 "Is the person currently/ever attended school?"
rename s02q03 inschool


local vars "read_french read_locallanguage read_other write_french write_locallanguage write_other inschool"
foreach x of local vars {
	label values `x' yesno
	}

label variable s02q04 "Why didn't his person attend a formal school"
rename s02q04 whynoschool
label values whynoschool whynoschool

label variable s02q05 "Did the person attend a non-formal school/training"
rename s02q05 training
label variable s02q06 "Type of non-formal schooling attended?"
rename s02q06 nonformal
label values nonformal nonformal



label variable s02q07 "Age when the person started school"
rename s02q07 age_schoolstart
label variable s02q14 "Highest level of education attained - those in school last year"
rename s02q14 education_currinsch
label values education_currinsch higheduc
label variable s02q15 "Career path - those in school last year"
rename s02q15 career_currinsch
label variable s02q16 "last grade attended - those in school last year"
rename s02q16 gradecompleted_currinsch


label variable s02q29 "Highest level of education attained"
rename s02q29 education
label values education higheduc

label variable s02q30 "Field of study"
rename s02q30 fieldofstudy
label values fieldofstudy field


label variable s02q31 "What is the last class attended in the declared level"
rename s02q31 lastclass
label variable s02q32 "What is the last year the person attended school"
rename s02q32 lastyear_school
replace lastyear_school=. if lastyear_school>2020

label variable s02q33 "What is the highest degree earned by the person?"
rename s02q33 degree
label values degree degree


local vars "inschool training"
foreach x of local vars {
	replace `x'=0 if `x'==2
	label values `x' yesno
	}



drop s00q08 s00q27 s01q00b s02q00 s02q04_autre s02q08-s02q13 s02q17-s02q28 s02q30_autre s01q02

merge 1:1 interview__id member_id using "$reproduce_files/EHCVM Roster.dta"
drop _merge

save "$reproduce_files/EHCVM Roster.dta", replace



/***************HEALTH CONDITION***************/


use "$ehcvm_input\s03_me_BFA2018.dta", clear


label define yesno 1 "Yes" 0 "No"

label define mosquitonet 1 "Impregnated mosquito net" 2 "Single Screen" 3 "No"

label define mosquitoprevent 1 "Insectides" 2 "anti-mosquito cream" 3 "spirals" 4 "screening on window" 5 "other" 6 "nothing"

label define difficulty 1 "no" 2 "yes a little" 3 "Yes alot" 4 "can't at all"


label variable s01q00a "HH Member ID"
rename s01q00a member_id

/*note, the two questions in the survey are listed as questions 35 and 36 respectively, but in the dataset, they are listed as 39 and 40*/
label variable s03q39 "Does the person sleep under mosquito net last night?"
rename s03q39 mosquitonet_type
label values mosquitonet_type mosquitonet

label variable s03q40 "What are the different ways the person protects themselves from mosquitos?"
rename s03q40 mosquito_protection
label values mosquito_protection mosquitoprevent

/*note, the two questions in the survey are listed as questions 37 through 42 respectively, but in the dataset, they are listed as questions 41 to and 46*/
label variable s03q41 "Does the person have difficulty seeing, even with glasses?"
rename s03q41 difficulty_seeing
label values difficulty_seeing difficulty

label variable s03q42 "Does the person have difficulty hearing?"
rename s03q42 difficulty_hearing
label values difficulty_hearing difficulty

label variable s03q43 "Does the person have difficulty walking/climbing stairs?"
rename s03q43 difficulty_walking
label values difficulty_walking difficulty

label variable s03q44 "Does the person have difficulty remembering?"
rename s03q44 difficulty_remembering
label values difficulty_remembering difficulty

label variable s03q45 "Does the person have difficulty bathing/dressing?"
rename s03q45 difficulty_grooming
label values difficulty_grooming difficulty

label variable s03q46 "Does the person have difficulty communicating?"
rename s03q46 difficulty_communicating
label values difficulty_communicating difficulty


drop s00q08 s00q27 interview__key s01q00b s03q00- s03q38 s01q02



merge 1:1 interview__id member_id using "$reproduce_files/EHCVM Roster.dta"
drop _merge

save "$reproduce_files/EHCVM Roster.dta", replace


/*********************HOUSING***********************/

use "$ehcvm_input\s11_me_BFA2018.dta", clear

label define housetype 1 "Modern House" 2 "building/apartment" 3 "single family" 4 "celibaterium" 5 "single family in banco" 6 "traditional house in banco" 7 "case/paille" 8 "other"

label define yesno 1 "yes" 0 "no"

label define ownership 1 "owner with title" 2 "owner without title" 3 "co-owner with title" 4 "co-owner without title" 5 "tenant" 6 "housed by employer" 7 "housed for free" 8 "other"

label define wall 1 "cement" 2 "baked bricks" 3 "aluminum" 4 "improved banco" 5 "recovered materials" 6 "traditional material" 7 "straw" 8 "other"

label define roof 1 "cement" 2 "tile" 3 "sheets" 4 "straw" 5 "banco" 6 "chaume" 7 "mats" 8 "others" 

label define floor 1 "tile" 2 "cement" 3 "clay" 4 "animal dung" 5 "others"

label define electricity 1 "Yes connected to power grid" 2 "Yes house connected to neighbor's house" 3 "directly to pole" 4 "not connected"

label define light 1 "grid electricity" 2 "electricity from generator" 3 "oil lamp" 4 "battery lamp" 5 "parrafin/wood/board" 6 "solar plate" 7 "other"


label variable s11q01 "Type of house"
rename s11q01 house_type
label variable s11q02 "Rooms in the house"
rename s11q02 room
label variable s11q03__1 "Does the house have air conditioning?"
rename s11q03__1 airconditioning
label variable s11q03__2 "Does the house have a water heater?"
rename s11q03__2 waterheater
label variable s11q03__3 "Does the house have a ceiliing fan"
rename s11q03__3 ceilingfan


label variable s11q04 "What is the status of the ownership of the house?"
rename s11q04 ownership_status
label values ownership_status ownership

label variable s11q05 "Rent paid for the house"
rename s11q05 rent
label variable s11q06 "is the rent paid by someone who doesn't live in HH?"
rename s11q06 rent_paid
replace rent_paid=0 if rent_paid==2

label variable s11q08 "How much of the rent is paid by the third party?"
rename s11q08 rent_paid_thirdparty
label variable s11q16 "Did HH pay any loan repayment for this house?"
rename s11q16 loanpayments
replace loanpayments=0 if loanpayments==2

label variable s11q17 "Monthly amount paid"
rename s11q17 loan_paid
label variable s11q18 "Does the HH operate a business within the HH?"
rename s11q18 hh_business
replace hh_business=0 if hh_business==2


label variable s11q19 "What is the material for the wall?"
rename s11q19 wall
label values wall wall

label variable s11q20 "What is the main roof material?"
rename s11q20 roof
label values roof roof

label variable s11q21 "What is the main floor material?"
rename s11q21 floor
label values floor floor

label variable s11q22 "Does the HH have piped water?"
rename s11q22 pipedwater
replace pipedwater=0 if pipedwater==2

label variable s11q28 "Distance to get water in dry season (meters)"
rename s11q28 water_distance_dry
label variable s11q29a "How many minutes is needed to get to water source in dry season?"
rename s11q29a time_water_dry
label variable s11q30 "Distance to get water in wet season (meters)"
rename s11q30 water_distance_wet
label variable s11q31a "How many minutes needed to get to water source in rainy season?"
rename s11q31a time_water_wet
label variable s11q34 "Does the HH have electricity?"
rename s11q34 electricity
label values electricity electricity

label variable s11q38 "Primary source of lighting in house?"
rename s11q38 light_source
label values light_source light


local vars "airconditioning waterheater ceilingfan rent_paid loanpayments hh_business"
foreach x of local vars {
	label values `x' yesno
	}


drop s00q08 s00q27 grappe s11q00 s11q01_autre s11q04_autre s11q07 s11q07_autre s11q09a- s11q15 s11q19_autre s11q20_autre s11q21_autre s11q23- s11q27b_autre s11q29b_heure s11q29b_minute s11q31b_heure s11q31b_minutes s11q32- s11q33_autre s11q35- s11q37b s11q39- s11q61_autre s11q38_autre


merge 1:1 interview__id using "$reproduce_files\EHCVM Household data.dta"
drop _merge
merge 1:1 interview__id using "$reproduce_files\EHCVM hhweight.dta"
drop _merge
save "$reproduce_files\EHCVM Household data.dta", replace


/*other assets*/
use "$ehcvm_input\s12_me_BFA2018.dta", clear

gen living_diningroom=0
replace living_diningroom=1 if s12q01==1 & s12q02==1 
replace living_diningroom=1 if s12q01==2 & s12q02==1 

gen cabinet=0
replace cabinet=1 if s12q01==5 & s12q02==1 

gen stove=0
replace stove=1 if s12q01==9  & s12q02==1
replace stove=1 if s12q01==10  & s12q02==1
replace stove=1 if s12q01==11  & s12q02==1

gen elec_app_small=0
replace stove=1 if s12q01==12  & s12q02==1
replace stove=1 if s12q01==13  & s12q02==1
replace stove=1 if s12q01==14  & s12q02==1

gen fridge=0
replace fridge=1 if s12q01==16  & s12q02==1  
replace fridge=1 if s12q01==17  & s12q02==1

gen fan=0
replace fan=1 if s12q01==18 & s12q02==1 

gen radio=0
replace radio=1 if s12q01==19 & s12q02==1 

gen tv=0
replace tv=1 if s12q01==20 & s12q02==1 

gen car=0
replace car=1 if s12q01==28 & s12q02==1 

gen motorcycle=0
replace motorcycle=1 if s12q01==29 & s12q02==1 

gen bicycle=0
replace bicycle=1 if s12q01==30 & s12q02==1 

gen cellphone=0
replace cellphone=1 if s12q01==35 & s12q02==1 


preserve 

rename s12q05__0 owner_person1
rename s12q05__1 owner_person2
rename s12q05__2 owner_person3


keep interview__id s12q01 car motorcycle bicycle owner_person1 owner_person2 owner_person3
keep if s12q01>=28 & s12q01<=30
reshape long owner_person, i(interview__id s12q01) j(person_id)
drop if owner_person==.
drop if owner_person==.a
drop person_id
rename owner_person member_id
collapse (max) motorcycle bicycle car, by(interview__id member_id)

gen vehicle=0
replace vehicle=1 if car==1
replace vehicle=1 if motorcycle==1 
replace vehicle=1 if bicycle==1 

drop car motorcycle bicycle

merge 1:1 interview__id member_id using "$reproduce_files/EHCVM Roster.dta"
replace vehicle=0 if vehicle==.
drop _merge
save "$reproduce_files/EHCVM Roster.dta", replace

restore


collapse (max) living_diningroom cabinet stove elec_app_small fridge fan radio tv car motorcycle bicycle cellphone, by(interview__id)
merge 1:1 interview__id using "$reproduce_files\EHCVM Household data.dta"
drop _merge
save "$reproduce_files\EHCVM Household data.dta", replace

/***********************AGRICULTURE*********************/

use "$ehcvm_input\s16a_me_BFA2018.dta", clear

label define plot_mgmt 1 "Individual" 2 "Collective"
label define units 1 "Hectare" 2 "meter squared"
label define ownership_plot 1 "owner" 2 "free loan" 3 "closing" 4 "shoring" 5 "gage" 6 "others"
label define how_purchased 1 "purchse" 2 "inheritance" 3 "marriage" 4 "gift" 5 "other"
label define document_parcel 1 "land title" 2 "farming permit" 3 "verbal report" 4 "lease" 5 "sale agreement" 6 "other" 7 "none"
label define mainlandconcern 1 "land boundary dispute" 2 "ownership related to inheritance" 3 "ownership related to sale" 4 "ownership expropriation" 5 "others"
label define watersource_land 1 "irrigation, own well" 2 "irrigation canal" 3 "irrigation stream" 4 "rainfall" 5 "marshes" 6 "others"
label define soiltype 1 "sandy" 2 "silty" 3 "clay" 4 "glacis" 5 "others"
label define topography 1 "hill" 2 "plain" 3 "gentle slope" 4 "steep slope" 5 "valley" 6 "others"
label define land_fertility 1 "good" 2 "medium" 3 "low"


label variable s16aq02 "agriculture field sequence number"
rename s16aq02 field_id
label variable s16aq03 "ID of the parcel in the field"
rename s16aq03 parcels
label variable s16aq04 "id of the person who farms"
rename s16aq04 person_id_farm
label variable s16aq05 "Is the plot under individual/collective mgmt?"
rename s16aq05 plot_mgmt
label variable s16aq06 "Serial number of the person who farms this pacel"
rename s16aq06 member_id
label variable s16aq08 "what is the main crop grown in the field?"
rename s16aq08 maincrop_id
label variable s16aq09a "area of the plot of land"
rename s16aq09a area
label variable s16aq09b "measurement units "
rename s16aq09b units
label variable s16aq10 "What is the ownership of the plot of agricultural land?"
rename s16aq10 ownership_plot
label variable s16aq11 "ID of the owner of the plot"
rename s16aq11 owner_id
label variable s16aq12 "How was the parcel of ag. land purchased?"
rename s16aq12 how_purchased
label variable s16aq13 "Do you have a legal document that shows ownership of parcel?"
rename s16aq13 document_parcel

forvalues i=0/59 {
	rename s16aq14__`i' legalowner_`i'
	label variable legalowner_`i' "ID of owner listed in document"
	}

label variable s16aq16 "What is the main concern about land rights? "
rename s16aq16 mainlandconcern
label variable s16aq17 "What is the main source of water for this agricultural land?"
rename s16aq17 watersource_land
label variable s16aq18 "What is the type of soil for this land?"
rename s16aq18 soiltype
label variable s16aq19 "Topography of the land"
rename s16aq19 topography
label variable s16aq20 "How would you assess the fertility of the land?"
rename s16aq20 land_fertility
label variable s16aq21 "how long does it take to go to your land?"
rename s16aq21 land_distance
unique interview__id
sort interview__id

label variable s16aq24a "quantity of manure applied"
rename s16aq24a manure_quanitity
label variable s16aq24b "units of the quantity of manure applied"
rename s16aq24b manure_units
label variable s16aq28 "How many times applied inorganic fertilizers this season?"
rename s16aq28 times_fertilizer
label variable s16aq29a1 "quantity of urea applied"
rename s16aq29a1 urea_quantity
label variable s16aq29a2 "units of the quantity of urea applied"
rename s16aq29a2 urea_units
label variable s16aq29b1 "quantity of phosphates applied"
rename s16aq29b1 phosphates_quantity
label variable s16aq29b2 "units of the quantity of phosphates applied"
rename s16aq29b2 phosphates_units
label variable s16aq29c1 "quantity of npk applied"
rename s16aq29c1 npk_quantity
label variable s16aq29c2 "units of the quantity of npk applied"
rename s16aq29c2 npk_units
label variable s16aq29d1 "quantity of dap applied"
rename s16aq29d1 dap_quantity
label variable s16aq29d2 "units of quantity of dap applied"
rename s16aq29d2 dap_units
label variable s16aq31a1 "quanitity of pesticides used"
rename s16aq31a1 pesticides_quantity
label variable s16aq31a2 "units of the quanitity of pesticides used"
rename s16aq31a2 pesticides_units
label variable s16aq31b1 "quanitity of fungicides used"
rename s16aq31b1 fungicides_quantity
rename s16aq31b2 fungicides_units
label variable fungicides_units "units of the quanitity of fungicides used"
label variable s16aq31c1 "quanitity of pesticides used"
rename s16aq31c1 herbicides_quantity
label variable s16aq31c2 "units of the quanitity of herbicides used"
rename s16aq31c2 herbicides_units
label variable s16aq31d1 "quantity of other plantproduction"
rename s16aq31d1 other_plantprotection_quantity
label variable s16aq31d2 "units of quantity of other plant protection"
rename s16aq31d2 other_plantprotection_units


label variable s16aq47 "land area according to GPS measurement"
rename s16aq47 landarea_gps
	
/*generating number of family members worked in farm, and days worked*/	
gen familymember_soilprep=0
label variable familymember_soilprep "number of family members worked in soil preparation"
gen familymember_soilprepdays=0
label variable familymember_soilprepdays "days offered by family members to soil preparation"

gen familymember_weeding=0
label variable familymember_weeding "number of family members worked in weeding"
gen familymember_weedingdays=0
label variable familymember_weedingdays "days offered by family members to weeding"

gen familymember_harvesting=0
label variable familymember_harvesting "number of family members worked in harvesting"
gen familymember_harvestingdays=0
label variable familymember_harvestingdays "days offered by family members to harvest"



forvalues i=1/28 {
		replace familymember_soilprep=familymember_soilprep+1 if s16aq33a_`i'>0 & s16aq33a_`i'<60 & s16aq33a_`i'!=.
		replace familymember_soilprepdays=familymember_soilprepdays+ s16aq33b_`i' if s16aq33b_`i'!=.
		
replace familymember_weeding=familymember_weeding+1 if s16aq35a_`i'>0 & s16aq35a_`i'<60 & s16aq35a_`i'!=.
		replace familymember_weedingdays=familymember_weedingdays+ s16aq35b_`i' if s16aq35b_`i'!=.
		
replace familymember_harvesting=familymember_harvesting+1 if s16aq37a_`i'>0 & s16aq37a_`i'<60 & s16aq37a_`i'!=.
		replace familymember_harvestingdays=familymember_harvestingdays+ s16aq37b_`i' if s16aq37b_`i'!=.
				
		}

forvalues i=1/33 {
		
replace familymember_harvesting=familymember_harvesting+1 if s16aq37a_`i'>0 & s16aq37a_`i'<60 & s16aq37a_`i'!=.
		replace familymember_harvestingdays=familymember_harvestingdays+ s16aq37b_`i' if s16aq37b_`i'!=.
				
		}
		

		
/*calculating total male and female farm workers*/
gen malemember_soilprep=0
label variable malemember_soilprep "number of male members worked in soil preparation"
gen malemember_soilprepdays=0
label variable malemember_soilprepdays "days offered by male members to soil preparation"

gen malemember_weeding=0
label variable malemember_weeding "number of male members worked in weeding"
gen malemember_weedingdays=0
label variable malemember_weedingdays "days offered by male members to weeding"

gen malemember_harvesting=0
label variable malemember_harvesting "number of male members worked in harvesting"
gen malemember_harvestingdays=0
label variable malemember_harvestingdays "days offered by male members to harvest"


gen femalemember_soilprep=0
label variable femalemember_soilprep "number of female members worked in soil preparation"
gen femalemember_soilprepdays=0
label variable femalemember_soilprepdays "days offered by female members to soil preparation"

gen femalemember_weeding=0
label variable femalemember_weeding "number of female members worked in weeding"
gen femalemember_weedingdays=0
label variable femalemember_weedingdays "days offered by female members to weeding"

gen femalemember_harvesting=0
label variable femalemember_harvesting "number of female members worked in harvesting"
gen femalemember_harvestingdays=0
label variable femalemember_harvestingdays "days offered by female members to harvest"


/*soil prep id*/
forvalues i=1/28 {
	rename s16aq33a_`i' soilprep_id`i'
	rename s16aq33b_`i' soilprep_days`i'

	rename s16aq35a_`i' weeding_id`i'
	rename s16aq35b_`i' weeding_days`i'

	rename s16aq37a_`i' harvesting_id`i'
	rename s16aq37b_`i' harvesting_days`i'
}


preserve
clear
use "$reproduce_files/EHCVM Roster.dta"
keep interview__id member_id female
rename member_id mergeid
save "$reproduce_files/tempfile.dta", replace
restore

local vars "soilprep weeding harvesting"
foreach x of local vars {
		forvalues i=1/28 {
			rename `x'_id`i' mergeid
			merge m:1 interview__id mergeid using "$reproduce_files/tempfile.dta"
			drop if _merge==2
			drop _merge
			rename mergeid `x'_id_`i'
			rename female female_`x'`i'
		}
	}
	

local vars "soilprep weeding harvesting"
foreach x of local vars {
	forvalues i=1/28 {
		replace femalemember_`x'=femalemember_`x'+1 if female_`x'`i'==1
		replace femalemember_`x'days=femalemember_`x'days+`x'_days`i' if female_`x'`i'==1

		replace malemember_`x'=malemember_`x'+1 if female_`x'`i'==0
		replace malemember_`x'days=malemember_`x'days+`x'_days`i' if female_`x'`i'==0
	}
}	

		
drop female_soilprep1- female_harvesting28		


/*hired men, women, boys and girls in farm*/
local vars "men women boys girls"
foreach x of local vars {
	local type="soilprep weeding harvesting"
	foreach y of local type {
		gen hired_`x'_`y'_number = 0
		label variable hired_`x'_`y'_number "number of `x' hired to do `x'"
		gen hired_`x'_`y'_days = 0
		label variable hired_`x'_`y'_days "days of `x' hired to do `x'"
		gen hired_`x'_`y'_salary = 0
		label variable hired_`x'_`y'_salary "salary of `x' hired to do `x'"
	}
}		

local vars "men women boys girls"
local n: word count `vars'
forvalues i=1/`n' {
	local a : word `i' of `vars'
	replace hired_`a'_soilprep_number = s16aq39a_`i'
	replace hired_`a'_soilprep_days = s16aq39b_`i'
	replace hired_`a'_soilprep_salary = s16aq39c_`i'
}


local vars "men women boys girls"
local n: word count `vars'
forvalues i=1/`n' {
	local a : word `i' of `vars'
	replace hired_`a'_weeding_number = s16aq41a_`i'
	replace hired_`a'_weeding_days = s16aq41b_`i'
	replace hired_`a'_weeding_salary = s16aq41c_`i'
}


local vars "men women boys girls"
local n: word count `vars'
forvalues i=1/`n' {
	local a : word `i' of `vars'
	replace hired_`a'_harvesting_number = s16aq43a_`i'
	replace hired_`a'_harvesting_days = s16aq43b_`i'
	replace hired_`a'_harvesting_salary = s16aq43c_`i'
}

drop s16aq39a_1 s00q08 s00q27 s16a01a s16aa01b s16aq07 s16aq08_autre s16aq10_autre s16aq12_autre s16aq13_autre s16aq15 s16aq16_autre s16aq17_autre s16aq18_autre s16aq19_autre s16aq22 s16aq23 s16aq32 - s16aq48 s16aq46__Timestamp - s16aq37b_33

local vars "plot_mgmt units ownership_plot how_purchased document_parcel mainlandconcern watersource_land soiltype topography land_fertility"
foreach x of local vars {
	label values `x' `x'
	}

merge m:1 interview__id using "$reproduce_files\EHCVM hhweight.dta"
drop _merge s16aq24b_autre s16aq25 s16aq26 s16aq27 s16aq29a2_autre s16aq29b2_autre s16aq29c2_autre s16aq29d2_autre s16aq30
	
save "$reproduce_files\EHCVM Agriculture.dta", replace

	
/*inputs used*/	
use "$ehcvm_input\s16b_me_BFA2018.dta", clear	

label define input_id 1 "organic fertilizer - animal waste" 2 "organic fertilizer - hh waste" 3 "urea" 4 "phosphates" 5 "npk/single formula" 6 "dap and other inorganic fertilizers" 7 "pesticides" 8 "herbicides" 9 "fungicides" 10 "other phytosanitary products" 11 "small millet seed" 12 "sorghum seed" 13 "corn seed" 14 "rice seed" 15 "other cereal seed" 16 "cotton seed" 17 "sesame seed" 18 "bean/cowpea seed" 19 "tuber plants/cuttings" 20 "other seeds" 

label define wgt 1 "gram" 2 "kg" 3 "tonne" 4 "liter" 5 "carton"

label define mkt 1 "cooperative" 2 "shop" 3 "selfproduction" 4 "other farmers or HH" 5 "animals in the field" 6 "state" 7 "grain bank" 8 "other"

label define donation 1 "other HH" 2 "state" 3 "ngo" 4 "other" 


label variable s16bq01 "Name of input used"
rename s16bq01 input_id
label values input_id input_id

label variable s16bq03a "Quantity of input used"
rename s16bq03a quantity_input
label variable s16bq03b "unit of measuring quantity_input"
rename s16bq03b input_unit
label values input_unit wgt

label variable s16bq04 "Where did you purchase the input"
rename s16bq04 purchase_input
label values purchase_input mkt

label variable s16bq05 "Did you get any of the input as a gift/donation?"
rename s16bq05 input_gift
label variable s16bq06 "Who gifted the input to you?"
rename s16bq06 input_gift_source
label values input_gift_source donation


label variable s16bq07a "Quantity of input as gift"
rename s16bq07a quantity_input_gift
label variable s16bq07b "Unit of the variable quantity_input_gift"
rename s16bq07b input_gift_unit
label values input_gift_unit wgt


label variable s16bq09a "Amout of input purchased"
rename s16bq09a quantity_input_bought
label variable s16bq09b "unit of hte variable quantity_input_bought"
rename s16bq09b input_bought_unit
label values input_bought_unit wgt


label variable s16bq09c "amount paid to buy input"
rename s16bq09c value_input
drop s00q08 s00q27 s16bq02 s16bq02_autre s16bq04_autre s16bq06_autre s16bq08
	
merge m:1 interview__id using "$reproduce_files\EHCVM hhweight.dta"
drop _merge
	
save "$reproduce_files\EHCVM Agriculture Input.dta", replace

/*output*/
use "$ehcvm_input\s16c_me_BFA2018.dta", clear

label define yesno 1 "yes" 0 "no"



label define storage_method 1 "grounds in the consession" 2 "grounds outside the concession" 3 "store" 4 "hangar" 5 "roof of the house" 6 "no storage method" 7 "others"

label define why_inventory 1 "self-consumption" 2 "sale at higher prices" 3 "sale for other needs" 4 "seed" 5 "other"

label define notsell 1 "insufficient for HH" 2 "low prices" 3 "seeds" 4 "lack of customers" 5 "no road/market" 6 "other"

label define weight 1 "kg" 2 "units" 3 "yuroba plat" 4 "fine" 5 "medium bag" 6 "large bag" 7 "other"

label define productstatus 1 "ears" 2 "grain" 3 "husked" 4 "unshelled" 5 "not concerned"



label variable s16cq02 "agriculture field sequence number"
rename s16cq02 field_id
label variable s16cq03 "ID of the parcel in the field"
rename s16cq03 parcels
label variable s16cq04 "crop grown in field"
rename s16cq04 crop_id

label variable s16cq06 "id of member who grew the crop"
rename s16cq06 member_id
label variable s16cq07 "What growing system did you use?"
rename s16cq07 crop_system
label variable s16cq08 "What percentage of the plot did the crop occupy?"
rename s16cq08 pct_crop
label variable s16cq09 "Type of seed used for this crop"
rename s16cq09 seed_type
tab s16cq10
tab s16cq11
label variable s16cq10 "Are you done with harvesting?"
rename s16cq10 harvesting_done
label variable s16cq11 "What percentage of harvesting left?"
rename s16cq11 harvesting_left
rename s16cq12a quantity_harvested
label variable s16cq12b "Units of quantity_harvested"
rename s16cq12b quantity_units
label variable s16cq12c "Status of the crops harvested"
rename s16cq12c harvest_status
label variable s16cq13a "Amout of harvest consumed"
rename s16cq13a harvest_consumed
label variable s16cq13b "Units of consumed_units"
rename s16cq13b consumed_units
label variable s16cq13c "Product status of harvest_consumed"
rename s16cq13c consumed_status

label variable s16cq14a "Amout of harvest donated"
rename s16cq14a harvest_donated
label variable s16cq14b "Units of donated_units"
rename s16cq14b donated_units
label variable s16cq14c "Product status of harvest_donated"
rename s16cq14c donated_status

label variable s16cq16a "Amout of harvest sold"
rename s16cq16a harvest_sold
label variable s16cq16b "Units of sold_units"
rename s16cq16b sold_units
label variable s16cq16c "Product status of harvest_donated"
rename s16cq16c sold_status


label variable s16cq17 "money made from the sale"
rename s16cq17 money_sales
label variable s16cq18 "who controls the money made from the sale"
rename s16cq18 control_money

label variable s16cq19 "Who did you sell your crops to"
rename s16cq19 seller
label variable s16cq20 "What is the primary method for storing crop"
rename s16cq20 storage_method
label variable s16cq21 "Any amount of this season's crop in inventory?"
rename s16cq21 inventory
label variable s16cq22a "quantity of the inventory"
rename s16cq22a inventory_quantity
label variable s16cq22b "Units of inventory_quantity"
rename s16cq22b inventory_units
label variable s16cq22c "status of inventory_quantity"
rename s16cq22c inventory_status
label variable s16cq23 "Why do you store crops?"
rename s16cq23 why_inventory
label variable s16cq24 "Do you plan to sell the inventory?"
rename s16cq24 inventory_sale
label variable s16cq25 "Why do you NOT plan to sell the inventory? "
rename s16cq25 why_inventory_sale
label variable s16cq26a "how much of the inventory do you plan to sell"
rename s16cq26a inventory_sale_plan
label variable s16cq26b "Units of inventory_sale_plan"
rename s16cq26b units_inventory_sale_plan
label variable s16cq26c "Status of inventory_sale_plan"
rename s16cq26c inventory_sale_plan_status
label variable s16cq27 "at what unit price do you plan on selling the inventory?"
rename s16cq27 potential_unitprice
label variable s16cq29__1 "difficulty selling crops due to road distance"
rename s16cq29__1 difficultyselling_roaddistance
label variable s16cq29__2 "Difficulty selling crops due to market distance"
rename s16cq29__2 difficultyselling_marketdistance
label variable s16cq29__3 "difficulty selling crops due to transporation cost"
rename s16cq29__3 difficultyselling_transportcost
label variable s16cq29__4 "difficulty selling crops due to impractical road"
rename s16cq29__4 difficultyselling_impracroad
label variable s16cq29__5 "Difficulty selling crops due to lack of customers"
rename s16cq29__5 difficultyselling_nocustomer
label variable s16cq29__6 "difficulty selling crops due to low prices"
rename s16cq29__6 difficultyselling_lowprice
label variable s16cq29__7 "difficulty selling crops due to other reasons"
rename s16cq29__7 difficultyselling_other

local vars "roaddistance marketdistance transportcost impracroad nocustomer lowprice"
foreach x of local vars {
	replace difficultyselling_`x'=0 if difficultyselling_`x'==2
	}

drop s00q08 s00q27 s16cq01 s16cq03b s16cq12b_autre s16cq13b_autre s16cq14b_autre s16cq15 s16cq19_autre s16cq20_autre s16cq22b_autre s16cq23_autre s16cq25_autre s16cq26b_autre s16cq28 s16cq29_autre


merge m:1 interview__id field_id parcels using "$reproduce_files\EHCVM Agriculture.dta"
drop _merge
save "$reproduce_files\EHCVM Agriculture.dta", replace



/*agriculture equipment*/
use "$ehcvm_input\s19_me_BFA2018.dta", clear

gen tractor=0
replace tractor=1 if s19q02==101 & s19q03==1

gen sprayer=0
replace sprayer=1 if s19q02==102 & s19q03==1

gen tiller=0
replace tiller=1 if s19q02==103 & s19q03==1

gen multicultivator=0
replace multicultivator=1 if s19q02==104  & s19q03==1

gen plough_axe=0
replace plough_axe=1 if s19q02==105 & s19q03==1
replace plough_axe=1 if s19q02==106 & s19q03==1
replace plough_axe=1 if s19q02==107 & s19q03==1
replace plough_axe=1 if s19q02==125 & s19q03==1

gen seeddrill=0
replace seeddrill=1 if s19q02==111 & s19q03==1

gen harrow=0
replace harrow=1 if s19q02==112 & s19q03==1

gen ploughinganimal=0
replace ploughinganimal=1 if s19q02==113 & s19q03==1

gen cart=0
replace cart=1 if s19q02==104 & s19q03==1

gen hives=0
replace hives=1 if s19q02==115 & s19q03==1

gen rice_corn_husker=0
replace rice_corn_husker=1 if s19q02==117 & s19q03==1
replace rice_corn_husker=1 if s19q02==118 & s19q03==1

gen threshing_machine=0
replace threshing_machine=1 if s19q02==119 & s19q03==1

gen motorpump=0
replace motorpump=1 if s19q02==121 & s19q03==1
replace motorpump=1 if s19q02==122 & s19q03==1

gen flipflop=0
replace flipflop=1 if s19q02==123 & s19q03==1

gen bundlingmachine=0
replace bundlingmachine=1 if s19q02==124 & s19q03==1

gen mower=0
replace mower=1 if s19q02==128 & s19q03==1

gen mill=0
replace mill=1 if s19q02==129 & s19q03==1

gen fertilizerspreader=0
replace fertilizerspreader=1 if s19q02==130 & s19q03==1

/*all except plough/axe, ploughing animals and cart*/
gen equipment=0
replace equipment=1 if tractor==1 | sprayer==1 | tiller==1 | multicultivator==1 | seeddrill==1 | harrow==1 | hives==1 | rice_corn_husker==1 | threshing_machine==1 | motorpump==1 | flipflop==1 | bundlingmachine==1 | mower==1 | mill==1 | fertilizerspreader==1


collapse (max) tractor - equipment, by(interview__id)

merge 1:m interview__id using "$reproduce_files\EHCVM Agriculture.dta"
drop _merge

order interview__id grappe interview__key menage vague field_id parcels crop_id member_id

local vars "tractor sprayer tiller multicultivator plough_axe seeddrill harrow ploughinganimal cart hives rice_corn_husker threshing_machine motorpump flipflop bundlingmachine mower mill fertilizerspreader equipment"
foreach x of local vars {
	replace `x'=0 if `x'==.
	}

save "$reproduce_files\EHCVM Agriculture.dta", replace



/*****************EMPLOYMENT***************************/

use "$ehcvm_input\s04_me_BFA2018.dta", clear

label define yesno 1 "yes" 0 "no"
label define professional_category 1 "senior manager" 2 "middle management" 3 "skilled worker" 4 "unskilled worker" 5 "laborer/housekeeper" 6 "intern with pay" 7 "intern without pay" 8 "family worker working in family business" 9 "own account worker (boss)
label define sector 1 "state/local authorities" 2 "public/semipublic company" 3 "pvt company" 4 "company association" 5 "household as employer of domestic staff" 6 "int. orgs."
label define frequency 1 "weekly" 2 "monthly" 3 "quarterly" 4 "annually"
label define principal_work 1 "in field/breeding/hunting/fishing" 2 "sole proprietor, no agriculture" 3 "public or private sector employee" 4 "parttime worker" 5 "apprentice"
label define lookfor 1 "public salary" 2 "private salary" 3 "agriculture" 4 "non-agriculture proprietor" 5 "indifferent"
label define whyjob 1 "loss of previous job" 2 "first job"
label define whenavailable 1 "immediately" 2 "in 15 days" 3 "between 15-30 days" 4 "more than one month"
label define whynotlook 1 "too young" 2 "student" 3 "too old" 4 "retired" 5 "housekeeper" 6 "illness/disability" 7 "does not want to work" 8 "waiting to start business" 9 "waiting to hear back from employer" 10 "lack of employment" 11 "don't know how to search" 12 "seasonal unemployment" 13 "other"
label define manage 1 "pension" 2 "rent/annuities" 3 "grant/transfer" 4 "savings" 5 "crops" 6 "food transfers" 7 "incharge of the family" 8 "mendie" 9 "other"
label define whynotwork 1 "leave/holiday" 2 "maternity leave" 3 "temporary cessation" 4 "sick leave" 5 "on strike" 6 "suspension" 7 "in training" 8 "others"

rename s01q00a member_id
sum s04q01
label variable s04q01 "during last seven days, hours spent shopping in the market?"
rename s04q01 hrs_market
label variable s04q02 "during last seven days, hours worked for domestic work?"
rename s04q02 hrs_domestic
label variable s04q03 "during last seven days, hours worked to take care of children/elderly?"
rename s04q03 hrs_care
label variable s04q04 "during last seven days, hours spent to get water"
rename s04q04 hrs_water
label variable s04q05 "during last seven days, hours spent to get wood"
rename s04q05 hrs_wood
label variable s04q06 "did you work at least one hour in field/raise animals?"
rename s04q06 work_field
label variable s04q07 "work at least one hour for money? "
rename s04q07 work_money
label variable s04q08 "did the person work at least one hour for someone outside of hh?"
rename s04q08 work_outsidehh
label variable s04q09 "did the person work as apprentice last 7 days?"
rename s04q09 apprentice
label variable s04q11 "Did the person have other job in the last 7 days?"
rename s04q11 other_job
label variable s04q12 "Why didn't the person work in the last 7 days?"
rename s04q12 whynotwork
label values whynotwork whynotwork

label variable s04q13 "did you work in a field of the hh without pay?"
rename s04q13 hh_work_wo_pay
label variable s04q14 "did you work outside without pay?"
rename s04q14 outside_work_wo_pay
label variable s04q15 "did you look for work in the last 30 days? q15"
rename s04q15 lookforwork
label variable s04q17 "did you look for work in the last 30 days? q17"
rename s04q17 lookforwork2

local vars "other_job apprentice work_outsidehh work_money work_field hh_work_wo_pay outside_work_wo_pay lookforwork lookforwork2"
foreach x of local vars {
	replace `x' = 0 if `x' ==2
	label values `x' yesno
	}



label variable s04q16 "if you are not working, how to you provide for your needs"
rename s04q16 earning_notworking
label values earning_notworking manage


label variable s04q18 "why didn't you look for work in last 30 days?"
rename s04q18 whynot_lookforwork
label values whynot_lookforwork whynotlook

label variable s04q19 "is person available for work now?"
rename s04q19 availableforwork
replace availableforwork=0 if availableforwork==2
label values availableforwork yesno

label variable s04q20 "When is the person available for work?"
rename s04q20 whenavailable
label values whenavailable whenavailable

label variable s04q23 "why is the person looking for a job?"
rename s04q23 whyjob
label values whyjob whyjob

label variable s04q24__1 "searching for job through personal relations, parents"
rename s04q24__1 lookjob_1
label variable s04q24__2 "look for jobs through competitions/employers"
rename s04q24__2 lookjob_2
label variable s04q24__3 "look for jobs through classified, internet"
rename s04q24__3 lookjob_3
label variable s04q24__4 "look for jobs through ANPE"
rename s04q24__4 lookjob_4
label variable s04q24__5 "look for jobs through placement firm"
rename s04q24__5 lookjob_5
label variable s04q24__6 "look for jobs through personal approach"
rename s04q24__6 lookjob_6
label variable s04q24__7 "look for jobs through other means"
rename s04q24__7 lookjob_7
forvalues i=1/7 {
	label values lookjob_`i' yesno
	}

label variable s04q25 "what type of employment are you looking for?"
rename s04q25 looking_emptype
label values looking_emptype lookfor

label variable s04q26 "what is the minimum monthly wage the person is looking for"
rename s04q26 reservationwage


tab s04q28a
tab s04q28b
tab s04q29a
label variable s04q28a "principal work in last 12 months"
rename s04q28a principal_work
label values principal_work principal_work

label variable s04q28b "secondary work in last 12 months"
rename s04q28b secondary_work
rename s04q29a profession
label variable s04q29b "code of the profession"
rename s04q29b profession_code
label variable s04q29c "description of secondary profession"
rename s04q29c secondary_profession
label variable s04q29d "code of the seccondary profession"
rename s04q29d secondary_profession_code
label variable s04q30a "what is the activity of the company where the person works"
rename s04q30a company_activity
label variable s04q31 "sector of employment"
rename s04q31 sector
label values sector sector

label variable s04q32 "how many months was the person employed"
rename s04q32 months_employed
label variable s04q34 "how many days of annual leave last 12 months"
rename s04q34 paidleave
label variable s04q36 "days of sick leave"
rename s04q36 sickleave
label variable s04q37 "how many hours per day is dedicated to job"
rename s04q37 hrsperday
label variable s04q38 "does the person contribute to cnss or carfo?"
rename s04q38 cnss
replace cnss=0 if cnss==2
label values cnss yesno

label variable s04q39 "professional category of the person"
rename s04q39 professional_category
label values professional_category professional_category

label variable s04q40 "paternity/maternity leave given"
rename s04q40 child_leave
replace child_leave=0 if child_leave==2
label values child_leave yesno

label variable s04q41 "days of paternity/maternity leave given"
rename s04q41 child_leave_days
label variable s04q43 "salary of the person"
rename s04q43 salary
label variable s04q43_unite "how frequently is salary paid, week/month/quarter/year"
rename s04q43_unite frequency
label values frequency frequency

label variable s04q45 "total bonuses from the job"
rename s04q45 bonuses
label variable s04q45_unite "frequency of paying bonuses"
rename s04q45_unite bonus_frequency
label values bonus_frequency frequency

label variable s04q46 "does the person get any other allowances?"
rename s04q46 allowances
replace allowances=2 if allowances==2
label values allowances yesno

label variable s04q47 "total value of the allowances"
rename s04q47 total_allowances
label variable s04q47_unite "frequency of allowances"
rename s04q47_unite allowances_frequency
label values allowances_frequency frequency

label variable s04q48 "does the company give you food"
rename s04q48 given_food
replace given_food=0 if given_food==2
label values given_food yesno

label variable s04q49 "total food allowances"
rename s04q49 total_food_allowances
label variable s04q49_unite "frequency of paying food allowances"
rename s04q49_unite food_allowance_frequency
label values food_allowance_frequency frequency

label variable s04q50 "did the person do any secondary job?"
rename s04q50 any_secondary_job
replace any_secondary_job=0 if any_secondary_job==2
label values any_secondary_job yesno


label variable s04q54 "months in secondary job last year"
rename s04q54 secondaryjob_month
label variable s04q55 "Days per month in the secondary job"
rename s04q55 secondaryjob_dayspermonth
label variable s04q56 "hours per day in secondary job"
rename s04q56 secondaryjob_hrsperday
label variable s04q58 "salary of secondary job"
rename s04q58 secondaryjob_salary
label variable s04q58_unite "frequency of paying salary in secondary job"
rename s04q58_unite secondaryjob_frequency
label values secondaryjob_frequency frequency

label variable s04q60 "bonus amount from secondary job"
rename s04q60 secondaryjob_bonus
label variable s04q60_unite "frequency of bonus in secondary job"
rename s04q60_unite secondaryjob_bonus_frequency
label values secondaryjob_bonus_frequency frequency

label variable s04q62 "total benefits in secondary job"
rename s04q62 secondaryjob_benefits
label variable s04q62_unite "frequency of benefits received in secondary job"
rename s04q62_unite secondaryjob_benefits_frequency
label values secondaryjob_benefits_frequency frequency

label variable s04q64 "amount of food given in seconrdy job"
rename s04q64 secondaryjob_food
label variable s04q64_unite "frequency of the amount of secondaryjob_food"
rename s04q64_unite secondaryjob_food_frequency
label values secondaryjob_food_frequency frequency

merge 1:1 interview__id member_id using "$reproduce_files\EHCVM Roster.dta"
drop _merge
save "$reproduce_files\EHCVM Roster.dta", replace




/***********************************NON-WAGE EARNINGS************************/

use "$ehcvm_input\s05_me_BFA2018.dta", clear


rename s01q00a member_id
label variable s05q01 "received retirement pension"
rename s05q01 pension
label variable s05q02 "amount of pension"
rename s05q02 pension_amt
label variable s05q03 "received widow pension"
rename s05q03 widow_pension
label variable s05q04 "amount of widow pension"
rename s05q04 widow_pension_amt
label variable s05q05 "received disability pension"
rename s05q05 disability_pension
label variable s05q06 "amount of disability pension"
rename s05q06 disability_pension_amt
label variable s05q07 "received alimony from divorce"
rename s05q07 alimony
label variable s05q08 "amount of alimony"
rename s05q08 alimony_amt
label variable s05q09 "received rental income"
rename s05q09 rental_income
label variable s05q10 "amount of rental income"
rename s05q10 rental_income_amt
label variable s05q11 "received income from movable/financial assets"
rename s05q11 income_finance
label variable s05q12 "income from movable/financial assets"
rename s05q12 income_finance_amt
label variable s05q13 "any other income"
rename s05q13 other_income
label variable s05q14 "amount of other income"
rename s05q14 other_income_amt


merge 1:1 interview__id member_id using "$reproduce_files\EHCVM Roster.dta"
drop _merge
save "$reproduce_files\EHCVM Roster.dta", replace


********************************SAVINGS AND CREDIT***************************/


use "$ehcvm_input\s06_me_BFA2018.dta", clear

label define yesno 1 "yes" 0 "no"
label define frequency 1 "week" 2 "month" 3 "quarter" 4 "semester" 5 "year" 6 "in one go" 7 "not specified"
label define loansource 1 "bank" 2 "rural bank/mfi" 3 "ngo" 4 "supplier" 5 "cooperative" 6 "other household" 7 "association" 8 "loan shark" 9 "other"
label define refuse 1 "incomplete file" 2 "no guarantee" 3 "low repayment capacity" 4 "other current credit" 5 "other"
label define whynoloan 1 "lack of credit institutions" 2 "don't know how to ask" 3 "does not meet the conditions" 4 "not sure if I will get one" 5 "not able to pay back" 6 "high interest rate" 7 "other current credit" 8 "not necessary" 9 "others"

rename s01q00a member_id
unique interview__id member_id
label variable s06q01__1 "do you have a bank account?"
rename s06q01__1 bankaccount
label variable s06q01__2 "do you have a post office account?"
rename s06q01__2 postaccount
label variable s06q01__3 "do you have an mfi account?"
rename s06q01__3 mfiaccount
label variable s06q01__4 "do you have a mobile banking account?"
rename s06q01__4 mobilebanking
label variable s06q01__5 "do you have a prepaid card"
rename s06q01__5 prepaidcard
label variable s06q03 "applied for loan/credit in last few months?"
rename s06q03 loan
replace loan=0 if loan==2
local vars "bankaccount postaccount mfiaccount mobilebanking prepaidcard loan"
foreach x of local vars {
	label values `x' yesno
	}


label variable s06q04 "why didn't you apply for loan"
rename s06q04 whyno_loan
label values whyno_loan whynoloan

label variable s06q06 "why was credit refused?"
rename s06q06 why_refused
label values why_refused refuse

label variable s06q07 "member of a self-help group?"
rename s06q07 selfhelp_member
replace selfhelp_member=0 if selfhelp_member==2
label values selfhelp_member yesno

label variable s06q10 "how much outstanding debt does person have?"
rename s06q10 outstandingdebt
label variable s06q11 "what was the debt used for?"
rename s06q11 debt_use
label variable s06q12 "where did you get the loan from?"
rename s06q12 source_loan
label values source_loan loansource

label variable s06q13b "year loan taken out"
rename s06q13b yearloan
label variable s06q14 "amount of last loan"
rename s06q14 last_loan_amt


label variable s06q15 "frequency of installment payment"
rename s06q15 repayment_frequency
label values repayment_frequency frequency

label variable s06q16 "number of installments of the last loan"
rename s06q16 installment_number
label variable s06q17 "amount paid in each installment"
rename s06q17 installmentpayment
label variable s06q18 "how many payments made in the last loan"
rename s06q18 payments_made

drop s01q00b s06q00 s06q02 s06q04_autre s06q05 s06q08 s06q09 s06q11_autre s06q12_autre s06q13a 

gen financial_account=0
replace financial_account=1 if bankaccount==1 | postaccount==1 | mfiaccount==1 | mobilebanking==1 


*merge m:1 interview__id using "$reproduce_files\EHCVM hhweight.dta"
*drop _merge

*keep interview__id member_id financial_account

save "$reproduce_files\EHCVM Credit.dta", replace


/*************NON-AGRICULTURE BUSINESS***************/

use "$ehcvm_input\s10_1_me_BFA2018.dta", clear

label define yesnoconcern 1 "yes" 2 "no" 3 "no concern"
label define yesno 1 "yes" 0 "no" 
label define rawmaterial_source 1 "public sector" 2 "large pvt business" 3 "small comm. business" 4 "large pvt non-comm. comp" 5 "small non-comm business" 6 "household" 7 "direct imports" 8 "picking up" 9 "NA"
label define buyersource 1 "public sector" 2 "large pvt business" 3 "small comm. business" 4 "large pvt non-comm. comp" 5 "small non-comm business" 6 "household" 7 "direct exports"
label define fundingsource 1 "own funds" 2 "help from parent in country" 3 "help from relative abroad" 4 "loan from another HH" 5 "loan of a self-help group" 6 "bank loan" 7 "loan/cooperative support" 8 "loan/ngo support" 9 "other"
label define premises 1 "office/workshop/store/garage" 2 "fixed station on public road" 3 "cellphone for public roads" 4 "at home" 5 "home custormers" 6 "cars" 7 "ambluant" 8 "others"
label define share 1 "<25% of total" 2 "25-50% of total" 3 "50-75% of total" 4 ">75% of total"
label define whyclose 1 "bankruptcy" 2 "seasonal activity" 3 "lack of customers" 4 "lack of manpower" 5 "lack of raw material/technical prob" 6 "created in year" 7 "closed for not paying taxes" 8 "health problems" 9 "insecurity" 10 "political instability" 11 "others"

label variable s10q01 "ID of the respondent"
rename s10q01 respondent_id
label variable s10q02 "made doughnuts, grilled meat, fruit juices, beer, bread or cakes to sell?"
rename s10q02 activity1
label variable s10q03 "made clothes, sandals"
rename s10q03 activity2
label variable s10q04 "construction (masonry, electricity, plumbing) or carpentry"
rename s10q04 activity3
label variable s10q05 "have commercial business "
rename s10q05 activity4
label variable s10q06 "doctor/engineer with own practice/office?"
rename s10q06 activity5
label variable s10q07 "service business or cab service"
rename s10q07 activity6
label variable s10q08 "own a restaurant"
rename s10q08 activity7
label variable s10q09 "rent chair/tables"
rename s10q09 activity8
label variable s10q10 "small business of making handicrafts?"
rename s10q10 activity9

forvalues i=0/9 {
	rename s10q12a__`i' businessowned`i'
	label variable businessowned`i' "business owned by the HH"
	}
	
drop s00q08 s00q27 s10q12a__10- s10q12a__59

rename s10q12b totalbusiness
label variable totalbusiness "total number of business owned by HH"


save "$reproduce_files\EHCVM Enterprises.dta", replace

use "$ehcvm_input\s10_2_me_BFA2018.dta", clear
merge m:1 interview__id grappe menage vague using "$reproduce_files\EHCVM Enterprises.dta"
drop s10q17a s10q17b s10q17c s10q18a s10q15__1 s10q15__0 s10q14 s10q13 s10q12a_2 s00q08 s00q27 _merge

rename s10q12a_1 enterprise_id
label variable s10q16 "main product sold by company"
rename s10q16 mainproduct
label variable s10q18__0 "ID of individual managing business"
rename s10q18__0 managing1
label variable s10q18__1 "ID of individual managing business"
rename s10q18__1 managing2
label variable s10q19a "ID of person managing the revenues of the business"
rename s10q19a revenue_manage1
label variable s10q19__0 "ID of person managing the revenues of the business"
rename s10q19__0 revenue_manage2
label variable s10q19__1 "ID of person managing the revenues of the business"
rename s10q19__1 revenue_manage3
label variable s10q20 "years company is in operation"
rename s10q20 years_operation
label variable s10q21 "how many non-HH owners own this coompany?"
rename s10q21 nonhh_owners
label variable s10q22 "share of HH profits"
rename s10q22 share_profits
label values share_profits share
label variable s10q23 "where is the business located"
rename s10q23 premises
label values premises premises

label variable s10q24 "is the premise owned or rented?"
rename s10q24 premises_owned
label define premises_owned 1 "owner" 2 "tenant"
label values premises_owned premises_owned

label variable s10q25 "value of the business"
rename s10q25 business_value
label variable s10q26 "does the company have electricity"
rename s10q26 electricity
label variable s10q27 "does the company have running water"
rename s10q27 runningwater
label variable s10q28 "does the company have a phone"
rename s10q28 phone

gen records=0
replace records=1 if s10q29==1
replace records=1 if s10q29==2
label variable records "does the company have written records"

label variable s10q30 "does the company have unique tax ID?"
rename s10q30 tax_id
label variable s10q31 "does the company have registration?"
rename s10q31 registered
label variable s10q32 "does the company have employees registered in cnss"
rename s10q32 employee_cnss
label variable s10q33 "what is the type of the company"
rename s10q33 type_of_company
label define typecomp 1 "sole proprietorship" 2 "cooperatives/economic interest groups"
label values type_of_company typecomp

label variable s10q34 "what is the main funding source to start business"
rename s10q34 fundingsource
label values fundingsource fundingsource
label variable s10q35 "does the company have machines"
rename s10q35 machines
label variable s10q36 "value of the machines"
rename s10q36 machine_value
label variable s10q37 "does the company have vehicles (cars/motorcycles)"
rename s10q37 vehicles
label variable s10q38 "value of the vehicles"
rename s10q38 value_vehicles
label variable s10q39 "does the company have furniture"
rename s10q39 furniture
label variable s10q40 "value of the furniture"
rename s10q40 furniture_value
label variable s10q41 "does the company have equipment/tools"
rename s10q41 equipment
local vars "electricity runningwater phone records tax_id registered employee_cnss equipment furniture vehicles machines"
foreach x of local vars {
	replace `x'=0 if `x'==2
	label values `x' yesno
	}

label variable s10q42 "value of the equipment/tools"
rename s10q42 equipment_value
label variable s10q43 "from where does the company buy its raw materials"
rename s10q43 rawmaterial_source
label values rawmaterial_source rawmaterial_source
label variable s10q44 "who is the main buyer of the output?"
rename s10q44 buyer_source
label values buyer_source buyersource

local letters "a b c d e f g h i j k l m n o"
local val: word count `letters'
forvalues t=1/`val' {
	local let : word `t' of `letters'
	rename s10q45`let' problem`t'
	label values problem`t' yesnoconcern
}

label variable problem1 "difficulty with supply of raw materials"
label variable problem2 "lack of consumers"
label variable problem3 "too much competition"
label variable problem4 "difficulty accessing credit"
label variable problem5 "difficulty recruiting qualified individuals"
label variable problem6 "lack of space"
label variable problem7 "difficulty in accessing equipment"
label variable problem8 "technial difficulties in manufacturing"
label variable problem9 "technical difficulties in management"
label variable problem10 "problems with access to electricity"
label variable problem11 "problems with power outages"
label variable problem12 "problems with other infrastructures"
label variable problem13 "problems with internet"
label variable problem14 "problems with insecurity"
label variable problem15 "too many regulations, taxes"

label variable s10q46 "amount of goods resold last 30 days"
rename s10q46 resold_lastmonth
label variable s10q47 "how much did it cost to make the resold goods"
rename s10q47 costofgoodsresold

label variable s10q48 "amount obtained from selling processed goods"
rename s10q48 sold_lastmonth
label variable s10q49 "how much did it cost to produce the processed goods?"
rename s10q49 costofgoodssold
label variable s10q50 "what is the value of services given by the company in last 30 days"
rename s10q50 services_lastmonth
label variable s10q51 "how much did you spend on intermediate (telephone, transportation)"
rename s10q51 cost_intermediate
label variable s10q52 "spent on elec, water, rent last month"
rename s10q52 utilities_lastmonth
label variable s10q53 "how much spent on service fees last month"
rename s10q53 servicefees_lastmonth
label variable s10q54 "how much did you spend on other fees last month"
rename s10q54 otherfees_lastmonth
label variable s10q55 "patent cost last year"
rename s10q55 patent_cost
label variable s10q56 "taxes paid last year"
rename s10q56 taxes
label variable s10q57 "non-statutory admin cost last year"
rename s10q57 admin_cost
label variable s10q58 "is the company active?"
rename s10q58 active
label variable s10q59 "how many months in operation last year"
rename s10q59 months_operation
label variable s10q60 "why wasn't the compay operating last 12 months"
rename s10q60 whyno_operation
label values whyno_operation whyclose

forvalues i=1/9 {
	rename s10q61a_`i' hh_member`i'
	label variable hh_member`i' "ID of HH member working in business"
	rename s10q61b_`i' months_worked`i'
	label variable months_worked`i' "months worked last year"
	rename s10q61c_`i' days_worked`i'
	label variable days_worked`i' "days worked per month"
	rename s10q61d_`i' hours_worked`i'
	label variable hours_worked`i' "hours worked per day"
	}


gen hh_femalemember=0
label variable hh_femalemember "number of female hh members worked business"
gen hh_femalemember_days=0
label variable hh_femalemember_days "days offered by female hh members to business"
	
gen hh_malemember=0
label variable hh_malemember "number of male hh members worked business"
gen hh_malemember_days=0
label variable hh_malemember_days "days offered by male hh members to business"
	

preserve
clear
use "$reproduce_files/EHCVM Roster.dta"
keep interview__id member_id female
rename member_id mergeid
save "$reproduce_files/tempfile.dta", replace
restore

	forvalues i=1/9 {
			rename hh_member`i' mergeid
			merge m:1 interview__id mergeid using "$reproduce_files/tempfile.dta"
			drop if _merge==2
			drop _merge
			rename mergeid hh_member`i'
			rename female female`i'
		}
	

	forvalues i=1/9 {
		replace hh_femalemember=hh_femalemember+1 if female`i'==1
		replace hh_femalemember_days=hh_femalemember_days+(months_worked`i' * days_worked`i') if female`i'==1

		replace hh_malemember=hh_malemember+1 if female`i'==0
		replace hh_malemember_days=hh_malemember_days+(months_worked`i' * days_worked`i') if female`i'==0	
		}



	
	
	

rename s10q62a_1 men_employees
label variable men_employees "number of men employed"
rename s10q62b_1 men_employees_days
label variable men_employees_days "days men worked"
rename s10q62c_1 men_employees_hours
label variable men_employees_hours "hours per day men worked"
rename s10q62d_1 men_employees_salary
label variable men_employees_salary "salary to men employees"


rename s10q62a_2 women_employees
label variable women_employees "number of women employed"
rename s10q62b_2 women_employees_days
label variable women_employees_days "days women worked"
rename s10q62c_2 women_employees_hours
label variable women_employees_hours "hours per day women worked"
rename s10q62d_2 women_employees_salary
label variable women_employees_salary "salary to women employees"
	
rename s10q62a_3 boys_employees
label variable boys_employees "number of boys employed"
rename s10q62b_3 boys_employees_days
label variable boys_employees_days "days boys worked"
rename s10q62c_3 boys_employees_hours
label variable boys_employees_hours "hours per day boys worked"
rename s10q62d_3 boys_employees_salary
label variable boys_employees_salary "salary to boys employees"

rename s10q62a_4 girls_employees
label variable girls_employees "number of girls employed"
rename s10q62b_4 girls_employees_days
label variable girls_employees_days "days girls worked"
rename s10q62c_4 girls_employees_hours
label variable girls_employees_hours "hours per day girls worked"
rename s10q62d_4 girls_employees_salary
label variable girls_employees_salary "salary to girls employees"

merge m:1 interview__id using "$reproduce_files\EHCVM hhweight.dta"
drop _merge

save "$reproduce_files\EHCVM Enterprises.dta", replace
