clear 



/******************************HOUSEHOLD ROSTER**************************************/
use "$lsms_input\emc2014_p1_individu_27022015.dta" 

label variable B2 "1=male 2=female"
rename B2 sex
label variable B4 "age in years"
rename B4 age
label variable B5 "relation to head"
rename B5 relation
label define relation 1 "household head" 2 "spouse" 3 "son/daughter" 4 "grandson/granddaughter" 5 "father/mother" 6 "brother/sister" 7 "other relative" 8 "domestic servant/house staff" 9 "unrelated"
label values relation relation
rename B6 maritalstatus
label define marital 1 "married monogamous" 2 "married polygamous" 3 "cohabitation" 4 "single" 5 "divorced" 6 "widowed"
label values maritalstatus marital
label variable B8 "religion of the individual"
rename B8 religion
label variable B12A "can the person read/write in french?"
rename B12A literate_french
label variable B12B "is the person literate in the national language"
rename B12B literate_natllang
label variable B14 "highest level of education attented"
rename B14 highest_education
label variable B15A "currently inschool"
rename B15A inschool
label define school 1 "None" 2 "Preschool" 3 "Primary" 4 "lower secondary" 5 "second cycle general" 6 "second cycle technical" 7 "superior"
label values highest_education school
label variable B16 "does the person have any disabiity"
rename B16 any_disability
drop B17 B18A B18B B18C B19 B20 B21 B22 B23 B24 B25A B25B B26 B27 B28 B29 B30 B31


/*female dummy*/
gen female=0
replace female=1 if sex==2

/*household size*/
gen one=1
sort zd menage
by zd menage: egen hh_size=sum(one)
drop one


/*calculating dependency ratio*/
gen one=1 if age>=0 & age<=15
replace one=1 if age>64
replace one=0 if one==.

sort zd menage
by zd menage: egen dep=sum(one)
gen dep_ratio=dep/hh_size



/*adding in hhweight*/
gen hhid=zd*1000+menage
merge m:1 hhid using "$lsms_input\emc2014_welfare.dta"
drop _merge

drop B3A B3B B3C B7 B9 B10 B11 B12C B13 B15B annee

save "$reproduce_files\LSMS household roster.dta", replace



/*****************************************EMPLOYMENT***********************************/
use "$lsms_input\emc2014_p2_emploi_27022015.dta", clear

/*
label variable W01 "Did person work, even without pay, or at least 1 hour last week?"
rename W01 employed
label variable W02 "type of work of this person?"
rename W02 type_work
label variable W03 "if this person didn't work, does this person have a job?"
rename W03 have_job
label variable W04 "why did the person not work in the last 7 days?"
rename W04 why_nowork
label variable W06 "Did the person look for job in the last 7 days?"
rename W06 lookforjob
label variable W07 "why didn't the person look for job?"
rename W07 whyno_lookforjob
label variable W12 "what ist he main activity of the company where the person is employed?"
rename W12 industry
label variable W12a "what is the activity of the person in the company?"
rename W12a activity
label variable W15 "how often is the person paid?"
rename W15 pay_frequency
label variable W23 "what is the professional category of the person?"
rename W23 sector_employment
*/

label variable E01 "was the person employed one hour outside of home?"
rename E01 employed
label variable E03 "was the person employed with/without pay in garden?"
rename E03 employed_familyfarm
label variable E05 "was the person employed in a family business?"
rename E05 employed_familybusiness
label variable E07 "did the person do part-time work?"
rename E07 parttime_work
label variable E09 "was the person an apprentice w/wo pay?"
rename E09 apprentice
label variable E14 "if without job, did the person look for a job in the last 7 days?"
rename E14 lookforjob
label variable E23A "title in the job"
rename E23A jobtitle
label variable E24 "in what industry does the company operate in?"
rename E24 industry
label variable E25 "In what sector does the person work in?"
rename E25 employment_sector
label define employment_sector 1 "senior executive" 2 "middle manager/supervisor" 3 "worker or qualified employee" 4 "unskilled worker" 5 "laborer" 6 "boss" 7 "own account worker" 8 "family helper" 9 "apprentice"
label values employment_sector employment_sector
label variable E29 "number of months in job?"
rename E29 months_job
label variable E32A "annual salary of the person from the job?"
rename E32A annual_salary
label variable E32B "bins of annual salary?"
rename E32B salary_bins
label define bins 1 "0-31k" 2 "31k-50k" 3 "50k-80k" 4 "80k-110k" 5 "110k-140k" 6 "140k-180k" 7 "180k-220k" 8 "220k-260k" 9 "260k+"
label values salary_bins bins
label variable E32C "frequency of salary bins"
rename E32C salary_bins_frequency
label define frequency 1 "day" 2 "week" 3 "month" 4 "year"
label values salary_bins_frequency frequency

label variable E34 "total benefits"
rename E34 benefits
label variable E34B "frequency of benefits"
rename E34B benefits_frequency
label values benefits_frequency frequency

label variable E36 "value of food if included in benefits"
rename E36 benefit_food
rename E36B benefit_food_frequency
label variable benefit_food_frequency "frequency of food benefit"
label values benefit_food_frequency frequency

drop E37 E38 E39 E40 E41 E42 E43 E44 E45 E46 E47 E48 E49 E50



label variable E52 "secondaryjob: in what industry does the company operate in?"
rename E52 secondaryjob_industry
label variable E53 "In what sector does the person work in?"
rename E53 secondaryjob_employment_sector
label values secondaryjob_employment_sector employment_sector
label variable E55 "months in the secondary job"
rename E55 secondaryjob_months
label variable E58A "salary of the person from the job?"
rename E58A secondaryjob_salary
label variable E58B "bins of secondaryjob salary?"
rename E58B secondaryjob_salary_bins
label values secondaryjob_salary_bins bins
label variable E58C "frequency of salary bins"
rename E58C secjob_salary_bins_freq
label values secjob_salary_bins_freq frequency

label variable E67A "other job salary"
rename E67A other_job_salary
label variable E67B "bins of other job salary"
rename E67B other_job_salary_bins
label variable E67C "frequency of other job salary"
rename E67C other_job_freq
label values other_job_freq frequency



save "$reproduce_files\LSMS wage employment.dta", replace

*merge 1:1 zd menage numind region milieu using "$reproduce_files\LSMS household roster.dta"


/********************************FAMILY BUSINESS********************************/
use "$lsms_input\emc2014_p2_entreprise_indiv1_27022105", clear



label variable ef01A "processing of agriculture/animal products"
rename ef01A businessactivity1
label variable ef01B "repair of fabrics/clothing/shoes"
rename ef01B businessactivity2
label variable ef01C "construction"
rename ef01C businessactivity3
label variable ef01D "trade"
rename ef01D businessactivity4
label variable ef01E "self-employed broad category"
rename ef01E businessactivity5
label variable ef01F "transportation"
rename ef01F businessactivity6
label variable ef01G "food, hotels restaurants"
rename ef01G businessactivity7
label variable ef01H "other services"
rename ef01H businessactivity8
label variable ef01I "non-agricultural activities"
rename ef01I businessactivity9
label variable ef01J "agricultural activities"
rename ef01J businessactivity10
label variable ef00 "id of the enterprise"
rename ef00 enterprise_id
label variable ef02 "id of the owner of the enterprise"
rename ef02 owner_id
label variable ef04 "activity code of the business"
rename ef04 activitycode
label variable ef07A "own machines"
rename ef07A machines
label variable ef07B "own rolling stock"
rename ef07B rollingstock
label variable ef07C "own office furniture"
rename ef07C furniture
label variable ef07D "own small tools"
rename ef07D smalltools
label variable ef09 "does the business have a tax id?"
rename ef09 tax_id
label variable ef10 "how is bookkeeping done in the business?"
rename ef10 bookkeeping
label variable ef14 "is the business in operation?"
rename ef14 inoperation
label variable ef17A "how many male employees?"
rename ef17A male_employees
label variable ef17B "how many female employees?"
rename ef17B female_employees
label variable ef18 "how many are non-owner employees?"
rename ef18 total_employees
label variable ef19 "how many are hh-members employees?"
rename ef19 employees_hhmember
label variable ef22 "revenue1 last 30 days"
rename ef22 revenue1
label variable ef23 "revenue2 last 30 days"
rename ef23 revenue2
label variable ef24 "revenue3 last 30 days"
rename ef24 revenue3
label variable ef25 "cost1 of last 30 days"
rename ef25 cost1
label variable ef26 "cost last 30 days"
rename ef26 cost2
label variable ef27 "cost last 30 days"
rename ef27 cost3
label variable ef28 "cost last 30 days"
rename ef28 cost4
label variable ef29 "cost last 30 days"
rename ef29 cost5
label variable ef30 "cost last 30 days"
rename ef30 cost6
label variable ef31 "tax cost last year"
rename ef31 cost7
label variable ef32 "cost last 30 days"
rename ef32 cost8
label variable ef33 "cost last 30 days"
rename ef33 cost9


save "$reproduce_files\LSMS enterprises.dta", replace


/**********************************AGRICULTURE*****************************/

use "$lsms_input\emc2014_agri_caracteristiques_parcelles.dta", clear

label variable V02 "id of the parcel"
rename V02 parcel_id
label variable V03 "ID of the respondent"
rename V03 respondent_id
label variable V04 "number of crops grown in field"
rename V04 crops_number
label variable V05A "name of main crop"
rename V05A maincrop
label variable V05B "id of crop"
rename V05B cropid
label variable V06 "area of the parcel"
rename V06 area
label variable V15 "owner of the parcel"
rename V15 parcel_owner
label variable V29 "any inorganic fertilizer used in the parcel?"
rename V29 inorganic_fertilizer
label variable V31AUNITE "urea units"
rename V31AUNITE urea
label variable V31BUNITE "phosphates units"
rename V31BUNITE phosphates
label variable V31CUNITE "npk units"
rename V31CUNITE npk
label variable V31DUNITE "dap units"
rename V31DUNITE dap
label variable V33AUNITE "pesticides units"
rename V33AUNITE pesticides
label variable V33BUNITE "fungicides units"
rename V33BUNITE fungicides
label variable V33CUNITE "herbicides units"
rename V33CUNITE herbicides
label variable V35ANBRJR "hh men number of soil prep days"
rename V35ANBRJR hh_men_soil_prep_days
label variable V35BNBRJR "hh women number of soiprep days"
rename V35BNBRJR hh_women_soil_prep_days
label variable V35CNBRJR "hh children soilprep days"
rename V35CNBRJR hh_children_soil_prep_days
label variable V37ANBRJR "hh men weeding days"
rename V37ANBRJR hh_men_weeding_days
label variable V37BNBRJR "hh women weeding days"
rename V37BNBRJR hh_women_weeding_days
label variable V37CNBRJR "hh children weeding days"
rename V37CNBRJR hh_children_weeding_days
label variable V39ANBRJR "hh men harvesting days"
rename V39ANBRJR hh_men_harvest_days
label variable V39BNBRJR "hh women harvesting days"
rename V39BNBRJR hh_women_harvest_days
label variable V39CNBRJR "hh children harvesting days"
rename V39CNBRJR hh_children_harvest_days


label variable V41ANBRJR "non-hh men number of soil prep days"
rename V41ANBRJR nonhh_men_soil_prep_days
label variable V41BNBRJR "non-hh women number of soiprep days"
rename V41BNBRJR nonhh_women_soil_prep_days
label variable V41CNBRJR "non-hh children soilprep days"
rename V41CNBRJR nonhh_children_soil_prep_days
label variable V43ANBRJR "non-hh men weeding days"
rename V43ANBRJR nonhh_men_weeding_days
label variable V43BNBRJR "non-hh women weeding days"
rename V43BNBRJR nonhh_women_weeding_days
label variable V43CNBRJR "non-hh children weeding days"
rename V43CNBRJR nonhh_children_weeding_days
label variable V45ANBRJR "non-hh men harvesting days"
rename V45ANBRJR nonhh_men_harvest_days
label variable V45BNBRJR "non-hh women harvesting days"
rename V45BNBRJR nonhh_women_harvest_days
label variable V45CNBRJR "non-hh children harvesting days"
rename V45CNBRJR nonhh_children_harvest_days


save "$reproduce_files\LSMS agriculture.dta", replace

/*agriculture equipment*/
use "$lsms_input\emc2014_agri_equipements.dta", clear


gen tractor=0
replace tractor=1 if CODEX1==101 & X2==1

gen sprayer=0
replace sprayer=1 if CODEX1==102 & X2==1

gen tiller=0
replace tiller=1 if CODEX1==103 & X2==1

gen multicultivator=0
replace multicultivator=1 if CODEX1==104 & X2==1

gen seeddrill=0
replace seeddrill=1 if CODEX1==107 & X2==1

gen rice_corn_husker=0
replace rice_corn_husker=1 if CODEX1==110 & X2==1
replace rice_corn_husker=1 if CODEX1==111 & X2==1

gen threshing_machine=0
replace threshing_machine=1 if CODEX1==112 & X2==1
replace threshing_machine=1 if CODEX1==113 & X2==1

gen motorpump=0
replace motorpump=1 if CODEX1==114 & X2==1
replace motorpump=1 if CODEX1==115 & X2==1

gen flipflop=0
replace flipflop=1 if CODEX1==116 & X2==1

gen bundlingmachine=0
replace bundlingmachine=1 if CODEX1==117 & X2==1

gen mower=0
replace mower=1 if CODEX1==118 & X2==1

gen mill=0
replace mill=1 if CODEX1==119 & X2==1

gen fertilizerspreader=0
replace fertilizerspreader=1 if CODEX1==120 & X2==1


gen equipment=0
replace equipment=1 if tractor==1 | sprayer==1 | tiller==1 | multicultivator==1 | seeddrill==1 | rice_corn_husker==1 | threshing_machine==1 | motorpump==1 | flipflop==1 | bundlingmachine==1 | mower==1 | mill==1 | fertilizerspreader==1


collapse (max) milieu region province tractor - equipment, by(zd menage)


merge 1:m zd menage using  "$reproduce_files\LSMS agriculture.dta"
drop _merge

/*removing a duplicate hh*/
sort zd menage parcel_id
quietly by zd menage parcel_id:  gen dup = cond(_N==1,0,_n)
tab dup
drop if dup>1
drop dup


keep zd - equipment parcel_id- area parcel_owner inorganic_fertilizer urea phosphates npk dap pesticides fungicides herbicides hh_men_soil_prep_days hh_women_soil_prep_days hh_children_soil_prep_days hh_men_weeding_days hh_women_weeding_days hh_children_weeding_days hh_men_harvest_days hh_women_harvest_days hh_children_harvest_days nonhh_men_soil_prep_days nonhh_women_soil_prep_days nonhh_children_soil_prep_days nonhh_men_weeding_days nonhh_women_weeding_days nonhh_children_weeding_days nonhh_men_harvest_days nonhh_women_harvest_days nonhh_children_harvest_days hhweight STRATA

save "$reproduce_files\LSMS agriculture.dta", replace

/*agriculture output*/
use "$lsms_input\emc2014_agri_caracteristiques_cultures.dta", clear

label variable Y02 "id of the parcel"
rename Y02 parcel_id
label variable Y04A "name of crop"
rename Y04A cropname
label variable Y04B "id of the crop"
rename Y04B crop_id
label variable Y07 "are you done harvesting?"
rename Y07 harvesting_done
tab harvesting_done
label variable Y09C "amount harvested in kg"
rename Y09C harvesting_amt
label variable Y22C "amount in kg sold"
rename Y22C amount_sold
label variable Y23 "what is the total amount made from the sale"
rename Y23 revenue_sold
label variable Y24 "who controls the income from the sale of the product"
rename Y24 sale_control

drop Y25 - Y31B
drop A9 - A12BMINUTE

keep zd menage parcel_id cropname crop_id harvesting_done harvesting_amt amount_sold revenue_sold sale_control hhweight milieu region province STRATA

merge m:1 zd menage parcel_id using "$reproduce_files\LSMS agriculture.dta"
drop _merge

save "$reproduce_files\LSMS agriculture.dta", replace


/***************************ASSET INDEX********************************/
use "$lsms_input\emc2014_p1_logement_27022015.dta"

/*adding banco as a good material*/
gen wall_material=0
replace wall_material=1 if L05>=1 & L05<=4
gen roof_material=0
replace roof_material=1 if L06>=3 & L06<=5 
gen floor_material=0
replace floor_material=1 if L07>=3 & L07<=4

gen home_electricity=0
replace home_electricity=1 if L08>=3 & L08<=5

gen pipedwater=0
replace pipedwater=1 if L09>=7 & L09<=8


/*home asset index*/
pca wall_material roof_material floor_material pipedwater home_electricity
predict wealth_home
xtile home_quintile=wealth_home, nq(5)

keep zd menage region province wealth_home home_quintile
save "$reproduce_files/asset_index.dta", replace

use "$lsms_input\emc2014_p1_biensdurables_27022015.dta", clear

gen motorcycle=0
replace motorcycle=1 if code_article==202 & pm1==1


gen bicycle=0
replace bicycle=1 if code_article==203 & pm1==1

gen radio=0
replace radio=1 if code_article==207 & pm1==1

gen tv=0
replace tv=1 if code_article==205 & pm1==1

gen cellphone=0
replace cellphone=1 if code_article==211 & pm1==1

gen stove=0
replace stove=1 if code_article==215 & pm1==1

gen fridge=0
replace fridge=1 if code_article==213 & pm1==1
replace fridge=1 if code_article==214 & pm1==1

gen ceilingfan=0
replace ceilingfan=1 if code_article==219 & pm1==1

gen living_diningroom=0
replace living_diningroom=1 if code_article==222 & pm1==1
replace living_diningroom=1 if code_article==225 & pm1==1


gen elec_app_small=0
replace elec_app_small=1 if code_article==217 & pm1==1
replace elec_app_small=1 if code_article==216 & pm1==1

/*appliance asset index*/
pca living_diningroom stove elec_app_small fridge radio tv motorcycle bicycle cellphone ceilingfan
predict wealth_appliances
xtile appliances_quintile=wealth_appliances, nq(5)

collapse (mean) wealth_appliances appliances_quintile, by(zd menage)

merge 1:1 zd menage using "$reproduce_files/asset_index.dta"
drop _merge
save "$reproduce_files/asset_index.dta", replace
