clear

use "$reproduce_files\EHCVM Household data.dta", clear

/*constructing asset index, using the following:
1. ceilingfan
2. home - wall, roof, floor
3. piped water
4. electricity
5. light source

home furniture and machinary

*/

/*adding banco as a good material*/
gen wall_material=0
replace wall_material=1 if wall>=1 & wall<=4
gen roof_material=0
replace roof_material=1 if roof>=1 & roof<=3 
replace roof_material=1 if roof==5
gen floor_material=0
replace floor_material=1 if floor>=1 & floor<=2

gen home_electricity=0
replace home_electricity=1 if electricity>=1 & electricity<=3

/*home asset index*/
pca wall_material roof_material floor_material pipedwater home_electricity
predict wealth_home
xtile home_quintile=wealth_home, nq(5)

/*appliance asset index*/
pca living_diningroom cabinet stove elec_app_small fridge fan radio tv cellphone ceilingfan
predict wealth_appliances
xtile appliances_quintile=wealth_appliances, nq(5)

keep interview__id urban wealth_home home_quintile wealth_appliances appliances_quintile region province

/*merging hh data with individual data*/
merge 1:m interview__id using "$reproduce_files\EHCVM Roster.dta"
drop _merge
merge 1:1 interview__id member_id using "$reproduce_files\EHCVM Credit.dta"
drop _merge

/*keeping population aged 15 and older*/
drop if age<15


gen workingage=0
replace workingage=1 if age>=15 & age<=64

gen lfp=0
replace lfp=1 if work_field==1 
replace lfp=1 if work_money==1 
replace lfp=1 if work_outsidehh==1 
replace lfp=1 if apprentice==1 
replace lfp=1 if other_job==1
replace lfp=1 if lookforwork==1
replace lfp=1 if lookforwork2==1

sum lfp [aw=hhweight]
sum lfp if gender==0 [aw=hhweight]
sum lfp if gender==1 [aw=hhweight]

gen lfp2=lfp
replace lfp2=1 if hh_work_wo_pay==1 | outside_work_wo_pay==1

sum lfp2 [aw=hhweight]
sum lfp2 if gender==0 [aw=hhweight]
sum lfp2 if gender==1 [aw=hhweight]



/*creating dummies*/
gen married=0
replace married=1 if maritalstatus==2 | maritalstatus==3 | maritalstatus==4
replace married=. if maritalstatus==.
gen single=0
replace single=1 if maritalstatus==1
replace single=. if maritalstatus==.
gen divorced=0
replace divorced=1 if maritalstatus>=6 & maritalstatus<=7
replace divorced=1 if maritalstatus==5
replace divorced=. if maritalstatus==.


/*years of education completed*/
gen education_years=.
forvalues i=1/6 {
	replace education_years=`i' if education==2 & lastclass==`i'
	replace education_years=`i' if education_currinsch==2 & gradecompleted_currinsch==`i'
		}
forvalues i=1/3 {
	local j=`i'+6
	replace education_years=`j' if education==3 | education==4 & lastclass==`i'
	replace education_years=`j' if education_currinsch==3 | education_currinsch==4 & gradecompleted_currinsch==`i'
	}
forvalues i=1/3 {
	local j=`i'+10
	replace education_years=`j' if education==5 | education==6 & lastclass==`i'
	replace education_years=`j' if education_currinsch==5 | education_currinsch==6 & gradecompleted_currinsch==`i'
	}

/*BAC+2 - technical education*/
forvalues i=1/2 {
	local j=`i'+13
	replace education_years=`j' if education==7 & lastclass==`i'
	replace education_years=`j' if education_currinsch==7 & gradecompleted_currinsch==`i'
	}	

forvalues i=1/4 {
	local j=`i'+13
	replace education_years=`j' if education==8 & lastclass==`i'
	replace education_years=`j' if education_currinsch==8 & gradecompleted_currinsch==`i'
	}	

	replace education_years=18 if education==8 & lastclass>=5
	replace education_years=18 if education_currinsch==8 & gradecompleted_currinsch>=5

	
	
	
/*completed primary, secondary BAC and college*/
gen primary=0
replace primary=1 if education_years>=6 & education_years<=8


/*education variables - education, education_currinsch
this variable measures secondary schooling and higher*/
gen secondary_completed=0
replace secondary_completed=1 if education_currinsch>=5 & education_currinsch<=8
replace secondary_completed=1 if education>=5 & education<=8


/*urban/rural*/
replace urban=0 if urban==2
label define urban 1 "urban" 0 "rural"
label values urban urban

gen age2 = age^2

/*generating monthly salary*/
gen monthly_income=salary if frequency!=.
label variable monthly_income "monthly salary from primary job"
replace monthly_income=monthly_income/7*30 if frequency==1
replace monthly_income=monthly_income/3 if frequency==3
replace monthly_income=monthly_income/12 if frequency==4

/*adding bonuses*/
replace monthly_income=(bonuses/7*20) + monthly_income if bonus_frequency==1
replace monthly_income=bonuses + monthly_income if bonus_frequency==2
replace monthly_income=bonuses/3 + monthly_income if bonus_frequency==3
replace monthly_income=bonuses/12 + monthly_income if bonus_frequency==4

/*adding allowances*/
replace monthly_income=(total_allowances/7*20) + monthly_income if allowances_frequency==1
replace monthly_income=total_allowances + monthly_income if allowances_frequency==2
replace monthly_income=total_allowances/3 + monthly_income if allowances_frequency==3
replace monthly_income=total_allowances/12 + monthly_income if allowances_frequency==4


/*adding food allowances*/
replace monthly_income=(total_food_allowances/7*20) + monthly_income if food_allowance_frequency==1
replace monthly_income=total_food_allowances + monthly_income if food_allowance_frequency==2
replace monthly_income=total_food_allowances/3 + monthly_income if food_allowance_frequency==3
replace monthly_income=total_food_allowances/12 + monthly_income if food_allowance_frequency==4



/*secondary income also included*/
gen total_income=secondaryjob_salary
replace total_income=total_income*4 if secondaryjob_frequency==1
replace total_income=total_income/3 if secondaryjob_frequency==3
replace total_income=total_income/12 if secondaryjob_frequency==4

/*adding benefits*/
replace total_income=total_income + secondaryjob_benefits/7*20 if secondaryjob_benefits_frequency==1
replace total_income=total_income + secondaryjob_benefits if secondaryjob_benefits_frequency==2
replace total_income=total_income + secondaryjob_benefits/12 if secondaryjob_benefits_frequency==4

/*adding bonus*/
replace total_income=total_income + secondaryjob_bonus/7*20 if secondaryjob_bonus_frequency==1
replace total_income=total_income + secondaryjob_bonus if secondaryjob_bonus_frequency==2
replace total_income=total_income + secondaryjob_bonus/12 if secondaryjob_bonus_frequency==4

/*adding food*/
replace total_income=total_income + secondaryjob_food/7*20 if secondaryjob_food_frequency==1
replace total_income=total_income + secondaryjob_food if secondaryjob_food_frequency==2
replace total_income=total_income + secondaryjob_food/3 if secondaryjob_food_frequency==3
replace total_income=total_income + secondaryjob_food/12 if secondaryjob_food_frequency==4

replace total_income=total_income + monthly_income if total_income!=. & monthly_income!=.
replace total_income=monthly_income if total_income==. & monthly_income!=.


label variable total_income "Total income from primary and secondary jobs"


sum total_income if gender==0 [aw=hhweight]
sum total_income if gender==1 [aw=hhweight]

/*converting all missing values to zero*/
replace total_income=0 if total_income==. | total_income<0
replace total_income=. if professional_category==. /*not known*/
replace total_income=. if professional_category==9 /*owner of business*/
replace total_income=. if professional_category==10 /*not known*/


gen asinhtot_inc = asinh(total_income)
replace asinhtot_inc=0 if  total_income<0
replace asinhtot_inc=0 if total_income==.
replace asinhtot_inc=. if professional_category==. /*not known*/
replace asinhtot_inc=. if professional_category==9 /*owner of business*/
replace asinhtot_inc=. if professional_category==10 /*not known*/



gen asinhy = asinh(monthly_income)
replace asinhy=0 if  monthly_income<0
replace asinhy=0 if monthly_income==.
replace asinhy=. if professional_category==. /*not known*/


replace monthly_income=0 if monthly_income==.
replace monthly_income=. if professional_category==. /*not known*/
replace monthly_income=. if professional_category==9 /*owner of business*/
replace monthly_income=. if professional_category==10 /*not known*/


winsor2 total_income monthly_income if female==1, cuts(1 99) replace
winsor2 total_income monthly_income if female==0, cuts(1 99) replace


gen manager=0
replace manager=1 if professional_category==1
replace manager=1 if professional_category==2
replace manager=. if professional_category==.
replace asinhy=. if professional_category==9 /*owner of business*/
replace asinhy=. if professional_category==10 /*not known*/



gen skilled_worker=0
replace skilled_worker=. if professional_category==.
replace skilled_worker=1 if professional_category==3

gen unskilled_worker=0
replace unskilled_worker=. if professional_category==.
replace unskilled_worker=1 if professional_category==4 
replace unskilled_worker=1 if professional_category==5

gen intern=0
replace intern=. if professional_category==.
replace intern=1 if professional_category==6
replace intern=1 if professional_category==7

gen family_worker=0
replace family_worker=. if professional_category==.
replace family_worker=1 if professional_category==8


/*what occupations are workers whose sector of employment is 'unskilled sector' doing

professional category of the person		Freq.	Percent	Cum.
			
skilled worker							27		5.21	5.21
unskilled worker						296		57.14	62.36
laborer/housekeeper						69		13.32	75.68
intern with pay							36		6.95	82.63
family worker working in family busines	8		1.54	84.17
*/			


/*sectors of employment*/
/*agriculture workers*/
gen agriculture_sector=0
replace agriculture_sector=1 if profession_code==6 
replace agriculture_sector=. if profession_code==12
replace agriculture_sector=. if profession_code==.


/*artisans and factory workers*/
gen manufacturing_sector=0
replace manufacturing_sector=1 if profession_code==7 | profession_code==8
replace manufacturing_sector=. if profession_code==12
replace manufacturing_sector=. if profession_code==.

/*govenment employees, intellectual professions, administrative cadres, sales, trade, unskilled (mainly in professional_category is also unskilled)*/
gen service_sector=0
replace service_sector=1 if profession_code==1 | profession_code==2 | profession_code==3 | profession_code==4 | profession_code==5
replace service_sector=1 if profession_code==9 | profession_code==10 | profession_code==11 
replace service_sector=. if profession_code==12
replace service_sector=. if profession_code==.

/*one cutoff*/
gen age30_64=0
replace age30_64=1 if age>=30 & age<=64

/*another cutoff*/
gen age15_29=0
replace age15_29=1 if age>=15 & age<=29

/*disability*/
gen disability = 1 
replace disability = 0 if difficulty_seeing==1 | difficulty_walking==1 | difficulty_hearing==1 | difficulty_remembering==1 | difficulty_communicating==1 
	
drop if age<15
drop if age>64

/*for calculating pct of people in each group*/
preserve
drop if monthly_income==.
keep interview__id member_id monthly_income female hhweight 
save temp1.dta, replace
restore 

		
/*******************************REGRESSIONS**************************/


/****************************LFP regressions**********************8*/	

global yvars "lfp"
global xvars "urban age age2 adults child0_5 financial_account married divorced secondary_completed vehicle wealth_appliances wealth_home disability"
 

/*constrained all*/
logit $yvars female $xvars  [iw=hhweight], vce(robust)

/*exporting summary statistics*/
outreg2 using "$reproduce_files\Table 1B Paid LFP.xls" if e(sample)==1 [aw=hhweight], excel replace sum(log) eqkeep(N mean sd) keep($yvars female $xvars)
outreg2 using "$reproduce_files\Table 1B Paid LFP.xls" if e(sample)==1 & female==0 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)
outreg2 using "$reproduce_files\Table 1B Paid LFP.xls" if e(sample)==1 & female==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)


/*constrained - age 15-29*/
logit lfp female $xvars if age15_29==1 [iw=hhweight], vce(robust)

/*exporting summary statistics*/
outreg2 using "$reproduce_files\Table 1B Paid LFP.xls" if e(sample)==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars female $xvars)
outreg2 using "$reproduce_files\Table 1B Paid LFP.xls" if e(sample)==1 & female==0 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)
outreg2 using "$reproduce_files\Table 1B Paid LFP.xls" if e(sample)==1 & female==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)



/*constrained - age 30-64*/
logit lfp female $xvars if age30_64==1 [iw=hhweight], vce(robust)

/*exporting summary statistics*/
outreg2 using "$reproduce_files\Table 1B Paid LFP.xls" if e(sample)==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars female $xvars)
outreg2 using "$reproduce_files\Table 1B Paid LFP.xls" if e(sample)==1 & female==0 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)
outreg2 using "$reproduce_files\Table 1B Paid LFP.xls" if e(sample)==1 & female==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)




/*running oaxaca-blinder decomposition*/
oaxaca $yvars $xvars [iw=hhweight], by(female) logit relax pooled vce(robust)
outreg2 using "$reproduce_files\Table 3.xls", excel se dec(3) replace  ctitle(all)



/*using a broader definition of LFP*/
global yvars "lfp2"

/*constrained all*/
logit $yvars female $xvars [iw=hhweight], vce(robust)


/*exporting summary statistics*/
outreg2 using "$reproduce_files\Table 1B Overall LFP.xls" if e(sample)==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars female $xvars)
outreg2 using "$reproduce_files\Table 1B Overall LFP.xls" if e(sample)==1 & female==0 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)
outreg2 using "$reproduce_files\Table 1B Overall LFP.xls" if e(sample)==1 & female==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)



/*constrained - age 15-29*/
logit $yvars female $xvars if age15_29==1 [iw=hhweight], vce(robust)


/*exporting summary statistics*/
outreg2 using "$reproduce_files\Table 1B Overall LFP.xls" if e(sample)==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars female $xvars)
outreg2 using "$reproduce_files\Table 1B Overall LFP.xls" if e(sample)==1 & female==0 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)
outreg2 using "$reproduce_files\Table 1B Overall LFP.xls" if e(sample)==1 & female==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)



/*constrained - age 30-64*/
logit $yvars female $xvars if age30_64==1 [iw=hhweight], vce(robust)

/*exporting summary statistics*/
outreg2 using "$reproduce_files\Table 1B Overall LFP.xls" if e(sample)==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars female $xvars)
outreg2 using "$reproduce_files\Table 1B Overall LFP.xls" if e(sample)==1 & female==0 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)
outreg2 using "$reproduce_files\Table 1B Overall LFP.xls" if e(sample)==1 & female==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)





/*running oaxaca-blinder decomposition*/
oaxaca $yvars $xvars [iw=hhweight], by(female) logit relax pooled vce(robust)
outreg2 using "$reproduce_files\Table 3.xls", excel se dec(3) append  ctitle(all)

oaxaca $yvars $xvars if age15_29==1 [iw=hhweight], by(female) logit relax pooled vce(robust)
outreg2 using "$reproduce_files\Appendix Table 2.xls", excel se dec(3) replace  ctitle(age 15-29)

oaxaca $yvars $xvars if age30_64==1 [iw=hhweight], by(female) logit relax pooled vce(robust)
outreg2 using "$reproduce_files\Appendix Table 2.xls", excel se dec(3) append  ctitle(age 30-64)

oaxaca $yvars $xvars if urban==1 [iw=hhweight], by(female) logit relax pooled vce(robust)
outreg2 using "$reproduce_files\Appendix Table 3.xls", excel se dec(3) replace  ctitle(urban population)

oaxaca $yvars $xvars if urban==0 [iw=hhweight], by(female) logit relax pooled vce(robust)
outreg2 using "$reproduce_files\Appendix Table 3.xls", excel se dec(3) append  ctitle(rural population)



/*******************************mincer regressions*******************************/

global yvars "monthly_income"
global xvars "urban age age2 adults child0_5 financial_account married divorced secondary_completed vehicle apprentice manager skilled_worker family_worker agriculture_sector manufacturing_sector service_sector"  


/*constrained - all*/
reg $yvars female $xvars [aw=hhweight], vce(robust)

/*exporting summary statistics*/
outreg2 using "$reproduce_files\Table 1B Wages.xls" if e(sample)==1 [aw=hhweight], excel replace sum(log) eqkeep(N mean sd) keep($yvars female $xvars)
outreg2 using "$reproduce_files\Table 1B Wages.xls" if e(sample)==1 & female==0 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)
outreg2 using "$reproduce_files\Table 1B Wages.xls" if e(sample)==1 & female==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)



/*constrained - 15-29 year olds*/
reg $yvars female $xvars if age15_29==1 [aw=hhweight], vce(robust)

/*exporting summary statistics*/
outreg2 using "$reproduce_files\Table 1B Wages.xls" if e(sample)==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars female $xvars)
outreg2 using "$reproduce_files\Table 1B Wages.xls" if e(sample)==1 & female==0 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)
outreg2 using "$reproduce_files\Table 1B Wages.xls" if e(sample)==1 & female==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)


/*constrained - 30-64 year olds*/
reg $yvars female $xvars if age30_64==1 [aw=hhweight], vce(robust)

/*exporting summary statistics*/
outreg2 using "$reproduce_files\Table 1B Wages.xls" if e(sample)==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars female $xvars)
outreg2 using "$reproduce_files\Table 1B Wages.xls" if e(sample)==1 & female==0 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)
outreg2 using "$reproduce_files\Table 1B Wages.xls" if e(sample)==1 & female==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)



/*removing some dummies to make them reference variables*/
global xvars "urban age age2 adults child0_5 financial_account married divorced secondary_completed vehicle apprentice manager skilled_worker agriculture_sector service_sector"  


/*running oaxaca-blinder decomposition*/
oaxaca $yvars $xvars [aw=hhweight], by(female) relax pooled vce(robust)
outreg2 using "$reproduce_files\Table 4.xls", excel se dec(3) replace  ctitle(All)

oaxaca $yvars $xvars if age15_29==1 [aw=hhweight], by(female) relax pooled vce(robust)
outreg2 using "$reproduce_files\Appendix Table 4.xls", excel se dec(3) replace ctitle(age 15-29)

oaxaca $yvars $xvars if age30_64==1 [aw=hhweight], by(female) relax pooled vce(robust)
outreg2 using "$reproduce_files\Appendix Table 4.xls", excel se dec(3) append ctitle(age 30-64)

oaxaca $yvars $xvars if urban==1 [iw=hhweight], by(female) relax pooled vce(robust)
outreg2 using "$reproduce_files\Appendix Table 5.xls", excel se dec(3) replace  ctitle(urban population)

oaxaca $yvars $xvars if urban==0 [iw=hhweight], by(female) relax pooled vce(robust)
outreg2 using "$reproduce_files\Appendix Table 5.xls", excel se dec(3) append  ctitle(rural population)




/*************************************enterprises**************************/
use "$reproduce_files\EHCVM Enterprises.dta", clear
rename managing1 member_id
merge m:1 interview__id member_id using "$reproduce_files\EHCVM Roster.dta"
drop if _merge==2
drop _merge
drop if enterprise_id==.
merge m:1 interview__id member_id using "$reproduce_files\EHCVM Credit.dta"
drop if _merge==2
drop _merge

egen revenue=rowtotal(resold_lastmonth sold_lastmonth services_lastmonth)
gen asinhrevenue=asinh(revenue)

replace patent_cost=patent_cost/months_operation
replace admin_cost=admin_cost/months_operation
replace taxes=taxes/months_operation


egen cost= rowtotal(costofgoodsresold costofgoodssold cost_intermediate utilities_lastmonth servicefees_lastmonth otherfees_lastmonth patent_cost taxes admin_cost)
gen salary1 = men_employees*men_employees_salary 
gen salary2 = women_employees*women_employees_salary 
gen salary3 = boys_employees*boys_employees_salary 
gen salary4 = girls_employees*girls_employees_salary
egen emp_salary=rowtotal(salary1 salary2 salary3 salary4)
gen profit = revenue - cost - emp_salary

gen asinhprofit=asinh(profit)
replace asinhprofit=0 if profit<0
replace asinhprofit=0 if profit==.


/*creating dummies*/
gen married=0
replace married=1 if maritalstatus==2 | maritalstatus==3 | maritalstatus==4
replace married=. if maritalstatus==.
gen single=0
replace single=1 if maritalstatus==1
replace single=. if maritalstatus==.
gen divorced=0
replace divorced=1 if maritalstatus>=6 & maritalstatus<=7
replace divorced=1 if maritalstatus==5
replace divorced=. if maritalstatus==.


/*years of education completed*/
gen education_years=.
forvalues i=1/6 {
	replace education_years=`i' if education==2 & lastclass==`i'
	replace education_years=`i' if education_currinsch==2 & gradecompleted_currinsch==`i'
		}
forvalues i=1/3 {
	local j=`i'+6
	replace education_years=`j' if education==3 | education==4 & lastclass==`i'
	replace education_years=`j' if education_currinsch==3 | education_currinsch==4 & gradecompleted_currinsch==`i'
	}
forvalues i=1/3 {
	local j=`i'+10
	replace education_years=`j' if education==5 | education==6 & lastclass==`i'
	replace education_years=`j' if education_currinsch==5 | education_currinsch==6 & gradecompleted_currinsch==`i'
	}

/*BAC+2 - technical education*/
forvalues i=1/2 {
	local j=`i'+13
	replace education_years=`j' if education==7 & lastclass==`i'
	replace education_years=`j' if education_currinsch==7 & gradecompleted_currinsch==`i'
	}	

forvalues i=1/4 {
	local j=`i'+13
	replace education_years=`j' if education==8 & lastclass==`i'
	replace education_years=`j' if education_currinsch==8 & gradecompleted_currinsch==`i'
	}	

	replace education_years=18 if education==8 & lastclass>=5
	replace education_years=18 if education_currinsch==8 & gradecompleted_currinsch>=5

/*completed primary, secondary BAC and college*/
gen primary=0
replace primary=1 if education_years>=6 & education_years<=8

/*education variables - education, education_currinsch
this variable measures secondary schooling and higher*/
gen secondary_completed=0
replace secondary_completed=1 if education_currinsch>=5 & education_currinsch<=8
replace secondary_completed=1 if education>=5 & education<=8


gen age2 = age^2
replace electricity=0 if electricity==.
replace runningwater=0 if runningwater==.
replace phone=0 if phone==.
replace records=0 if records==.
replace registered=0 if registered==.
replace machines=0 if machines==.
replace urban=0 if urban==2

replace registered=1 if tax_id==1 /*combining registered with tax ID*/

gen hhmember_employed=0
forvalues i=1/9 {
	replace hhmember_employed=hhmember_employed+1 if hh_member`i'!=.
	}

/*determining the threshold for youth*/
gen age15_19=0
replace age15_19=1 if age>=15 & age<=19

gen age20_24=0
replace age20_24=1 if age>=20 & age<=24

gen age25_29=0
replace age25_29=1 if age>=25 & age<=29

/*one cutoff*/
gen age20_29=0
replace age20_29=1 if age>=20 & age<=29

gen age30_64=0
replace age30_64=1 if age>=30 & age<=64

/*another cutoff*/
gen age15_24=0
replace age15_24=1 if age>=15 & age<=24

gen age25_64=0
replace age25_64=1 if age>=25 & age<=64


/*another cutoff*/
gen age15_29=0
replace age15_29=1 if age>=15 & age<=29
	

gen food_sector=0
replace food_sector=1 if activity1==1 | activity7==1	
	
gen clothing_sector=0
replace clothing_sector=1 if activity2==1 | activity9==1

gen construction=0
replace construction=1 if activity3==1	

gen service=0
replace service=1 if activity4==1 | activity5==1 | activity6==1 | activity8==1


drop if age<15
drop if age>64


/*for calculating pct of people in each group*/
preserve
drop if profit==.
keep interview__id member_id profit hhweight female
sort interview__id member_id
quietly by interview__id member_id:  gen dup = cond(_N==1,0,_n)
drop if dup>=2
drop dup
rename hhweight hhweight2
rename female female2
merge 1:1 interview__id member_id using temp1.dta
rename _merge merge2
save temp1.dta, replace
restore
	
	
replace men_employees = men_employees + boys_employees
replace women_employees = women_employees + girls_employees
	
	
global yvars "asinhrevenue"
global xvars "urban age age2 adults child0_5 financial_account married divorced secondary_completed vehicle electricity runningwater phone registered records machines men_employees women_employees hh_malemember_days hh_femalemember_days food_sector clothing_sector construction" 
	


/*constrained - all*/
reg $yvars female $xvars [aw=hhweight], vce(robust)

/*exporting summary statistics*/
outreg2 using "$reproduce_files\Table 1B BusRevenue.xls" if e(sample)==1 [aw=hhweight], excel replace sum(log) eqkeep(N mean sd) keep($yvars female $xvars service)
outreg2 using "$reproduce_files\Table 1B BusRevenue.xls" if e(sample)==1 & female==0 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars service)
outreg2 using "$reproduce_files\Table 1B BusRevenue.xls" if e(sample)==1 & female==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars service)


/*constrained - 15-29 year olds*/
reg $yvars female $xvars if age15_29==1 [aw=hhweight], vce(robust)

/*exporting summary statistics*/
outreg2 using "$reproduce_files\Table 1B BusRevenue.xls" if e(sample)==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars female $xvars service)
outreg2 using "$reproduce_files\Table 1B BusRevenue.xls" if e(sample)==1 & female==0 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars service)
outreg2 using "$reproduce_files\Table 1B BusRevenue.xls" if e(sample)==1 & female==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars service)


/*constrained - 30-64 year olds*/
reg $yvars female $xvars if age30_64==1 [aw=hhweight], vce(robust)

/*exporting summary statistics*/
outreg2 using "$reproduce_files\Table 1B BusRevenue.xls" if e(sample)==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars female $xvars service)
outreg2 using "$reproduce_files\Table 1B BusRevenue.xls"if e(sample)==1 & female==0 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars service)
outreg2 using "$reproduce_files\Table 1B BusRevenue.xls" if e(sample)==1 & female==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars service)





/*running oaxaca-blinder decomposition*/
oaxaca $yvars $xvars [aw=hhweight], by(female) relax pooled vce(robust)
outreg2 using "$reproduce_files\Table 5.xls", excel se dec(3) replace  ctitle(All)

oaxaca $yvars $xvars if age15_29==1 [aw=hhweight], by(female) relax pooled vce(robust)
outreg2 using "$reproduce_files\Appendix Table 6.xls", excel se dec(3) replace ctitle(age 15-29)

oaxaca $yvars $xvars if age30_64==1 [aw=hhweight], by(female) relax pooled vce(robust)
outreg2 using "$reproduce_files\Appendix Table 6.xls", excel se dec(3) append ctitle(age 30-64)

oaxaca $yvars $xvars if urban==1 [aw=hhweight], by(female) relax pooled vce(robust)
outreg2 using "$reproduce_files\Appendix Table 7.xls", excel se dec(3) replace  ctitle(urban population)

oaxaca $yvars $xvars if urban==0 [aw=hhweight], by(female) relax pooled vce(robust)
outreg2 using "$reproduce_files\Appendix Table 7.xls", excel se dec(3) append  ctitle(rural population)





/****************************************agriculture*****************************/
use "$reproduce_files\EHCVM Agriculture.dta" , clear 

merge m:1 interview__id member_id using "$reproduce_files\EHCVM Roster.dta"
drop if _merge==2
drop _merge
merge m:1 interview__id member_id using "$reproduce_files\EHCVM Credit.dta"
drop if _merge==2
drop _merge


/*creating dummies*/
gen married=0
replace married=1 if maritalstatus==2 | maritalstatus==3 | maritalstatus==4
replace married=. if maritalstatus==.
gen single=0
replace single=1 if maritalstatus==1
replace single=. if maritalstatus==.
gen divorced=0
replace divorced=1 if maritalstatus>=6 & maritalstatus<=7
replace divorced=1 if maritalstatus==5
replace divorced=. if maritalstatus==.


/*years of education completed*/
gen education_years=.
forvalues i=1/6 {
	replace education_years=`i' if education==2 & lastclass==`i'
	replace education_years=`i' if education_currinsch==2 & gradecompleted_currinsch==`i'
		}
forvalues i=1/3 {
	local j=`i'+6
	replace education_years=`j' if education==3 | education==4 & lastclass==`i'
	replace education_years=`j' if education_currinsch==3 | education_currinsch==4 & gradecompleted_currinsch==`i'
	}
forvalues i=1/3 {
	local j=`i'+10
	replace education_years=`j' if education==5 | education==6 & lastclass==`i'
	replace education_years=`j' if education_currinsch==5 | education_currinsch==6 & gradecompleted_currinsch==`i'
	}

/*BAC+2 - technical education*/
forvalues i=1/2 {
	local j=`i'+13
	replace education_years=`j' if education==7 & lastclass==`i'
	replace education_years=`j' if education_currinsch==7 & gradecompleted_currinsch==`i'
	}	

forvalues i=1/4 {
	local j=`i'+13
	replace education_years=`j' if education==8 & lastclass==`i'
	replace education_years=`j' if education_currinsch==8 & gradecompleted_currinsch==`i'
	}	

	replace education_years=18 if education==8 & lastclass>=5
	replace education_years=18 if education_currinsch==8 & gradecompleted_currinsch>=5

/*completed primary, secondary BAC and college*/
gen primary=0
replace primary=1 if education_years>=6 & education_years<=8


/*education variables - education, education_currinsch
this variable measures secondary schooling and higher*/
gen secondary_completed=0
replace secondary_completed=1 if education_currinsch>=5 & education_currinsch<=8
replace secondary_completed=1 if education>=5 & education<=8


gen age2 = age^2


/*crop grown*/
gen maize=0
replace maize=1 if crop_id==4
replace maize=. if crop_id==.

gen millet=0
replace millet=1 if crop_id==1
replace millet=. if crop_id==.

gen sorghum=0
replace sorghum=1 if crop_id==2
replace sorghum=. if crop_id==.

gen cotton=0
replace cotton=1 if crop_id==43
replace cotton=. if crop_id==.

gen export_crop=0
replace export_crop=1 if crop_id==43 /*cotton*/
replace export_crop=1 if crop_id==48 /*cocoa*/
replace export_crop=1 if crop_id==49 /*coffee*/
replace export_crop=1 if crop_id==51 /*Palm Oil*/
replace export_crop=1 if crop_id==52 /*Rubber Tree*/
replace export_crop=. if crop_id==.

/*manages the crop and also owns the field*/
gen manager_owner=0
replace manager_owner=1 if member_id == owner_id

gen female_manager_owner=0
replace female_manager_owner=1 if member_id == owner_id & female==1

gen male_manager_owner=0
replace male_manager_owner=1 if member_id == owner_id & female==0

/*assuming if control_money is missing, then plot manager controls the income*/
replace control_money=member_id if control_money==. & member_id!=.

/*manager controls the sales*/
preserve 
keep interview__id parcels member_id control_money 
rename member_id id 
rename control_money member_id
merge m:1 interview__id member_id using "$reproduce_files\EHCVM Roster.dta"
drop if _merge==2
keep interview__id parcels id member_id female
rename female female_control
label var female_control "female in hh control sale of crop"
rename member_id control_money
rename id member_id
save "$reproduce_files\temp_femalecontrol.dta", replace
restore

merge m:m interview__id member_id parcels control_money using "$reproduce_files\temp_femalecontrol.dta"
drop _merge 

gen manager_control = 0
replace manager_control = 1 if member_id==control_money
replace manager_control = 1 if member_id!=. & control_money==.

gen female_manager_control = 0
replace female_manager_control = 1 if member_id==control_money & female==1

gen male_manager_control = 0
replace male_manager_control = 1 if member_id==control_money & female==0



/*sum of family work*/
egen female_hh_totaldays = rowtotal(femalemember_soilprepdays femalemember_harvestingdays femalemember_weedingdays)
egen male_hh_totaldays = rowtotal(malemember_soilprepdays malemember_harvestingdays malemember_weedingdays)


/*obtaining the dependent variable*/
gen prop_sold=harvest_sold/quantity_harvested
sum prop_sold harvesting_left [aw=hhweight]


/*convert area of land to hectares*/
replace area=area/10000 if units==2
gen area_sq=area^2


/*winsorsize by men and women separately, removing bottom 1% and top 99%*/
winsor2 money_sales if female==1, cuts(1 99) replace
winsor2 money_sales if female==0, cuts(1 99) replace


gen sold_ha=money_sales/area /*productivity based on sales*/
gen price = (money_sales/harvest_sold)
preserve
keep price crop_id quantity_units
drop if price==.
rename price ave_price
collapse (mean) ave_price, by(crop_id quantity_units)
save crop_price.dta, replace
restore

merge m:1 crop_id quantity_units using crop_price.dta

gen prod_ha=(ave_price*quantity_harvested)/area /*productivity based on harvest*/

sum sold_ha prod_ha [aw=hhweight]

gen asinhprod=asinh(ave_price*quantity_harvested)
gen asinhsold=asinh(money_sales)
gen asinhprod_ha = asinh(prod_ha)
gen asinhsold_ha = asinh(sold_ha)


gen all_harvest_sold=0
replace all_harvest_sold=1 if quantity_harvested==harvest_sold & sold_units==quantity_units

gen clay_soil=0
replace clay_soil=1 if soiltype==3

gen sandy_soil=0
replace sandy_soil=1 if soiltype==1

gen silty_soil=0
replace silty_soil=1 if soiltype==2

gen fertility_good=0
replace fertility_good=1 if land_fertility==1

gen fertility_medium=0
replace fertility_medium=1 if land_fertility==2


/*fertilizers used - first converting to kilograms*/
local vars "urea phosphates npk dap pesticides fungicides herbicides"
foreach x of local vars {
	replace `x'_quantity=`x'_quantity*1000 if `x'_units==2
	replace `x'_quantity=`x'_quantity*50 if `x'_units==3
	replace `x'_quantity=0 if `x'_quantity==.
}

local vars "urea phosphates npk dap pesticides fungicides herbicides"
foreach x of local vars {
	gen `x'_use=0
	replace `x'_use=1 if `x'_quantity>0 & `x'_quantity!=.
	}

tabstat urea_use phosphates_use npk_use dap_use pesticides_use fungicides_use herbicides_use [aw=hhweight], stats(mean sd n)

gen fertilizer_use=0
replace fertilizer_use=1 if urea_use==1 | phosphates_use==1 | npk_use==1 | dap_use==1 
gen pestfungherb_use=0
replace pestfungherb_use=1 if pesticides_use==1 | fungicides_use==1 | herbicides_use==1


/*men farm labor*/
egen total_days_men = rowtotal(hired_men_soilprep_days hired_men_weeding_days hired_men_harvesting_days hired_boys_soilprep_days hired_boys_weeding_days hired_boys_harvesting_days)
egen total_days_women = rowtotal(hired_women_soilprep_days hired_women_weeding_days hired_women_harvesting_days hired_girls_soilprep_days hired_girls_weeding_days hired_girls_harvesting_days)
egen total_days_fam = rowtotal(familymember_soilprepdays familymember_weedingdays familymember_harvestingdays)


/*determining the threshold for youth*/
gen age15_19=0
replace age15_19=1 if age>=15 & age<=19

gen age20_24=0
replace age20_24=1 if age>=20 & age<=24

gen age25_29=0
replace age25_29=1 if age>=25 & age<=29

/*one cutoff*/
gen age20_29=0
replace age20_29=1 if age>=20 & age<=29

gen age30_64=0
replace age30_64=1 if age>=30 & age<=64

/*another cutoff*/
gen age15_24=0
replace age15_24=1 if age>=15 & age<=24

gen age25_64=0
replace age25_64=1 if age>=25 & age<=64


/*another cutoff*/
gen age15_29=0
replace age15_29=1 if age>=15 & age<=29


drop if age<15
drop if age>64


/*for calculating pct of people in each group*/
preserve
drop if asinhprod==.
keep interview__id member_id asinhprod hhweight female
sort interview__id member_id
quietly by interview__id member_id:  gen dup = cond(_N==1,0,_n)
drop if dup>=2
drop dup
rename hhweight hhweight3
rename female female3
merge 1:1 interview__id member_id using temp1.dta

gen weight=.
replace weight=hhweight
replace weight=hhweight2 if hhweight2!=.
replace weight=hhweight3 if hhweight3!=.

gen female_comb=0
replace female_comb=1 if female==1
replace female_comb=1 if female2==1
replace female_comb=1 if female3==1

save temp1.dta, replace
restore


/*using total harvest as a measure of productivity*/
global yvars "asinhprod"
global xvars "age age2 adults child0_5 financial_account married divorced secondary_completed vehicle equipment area area_sq land_distance export_crop manager_owner manager_control male_hh_totaldays female_hh_totaldays total_days_men total_days_women all_harvest_sold fertilizer_use pestfungherb_use" 

/*constrained - all*/
reg $yvars female $xvars [aw=hhweight], vce(robust)

/*exporting summary statistics*/
outreg2 using "$reproduce_files\Table 1B HarvestValue.xls" if e(sample)==1 [aw=hhweight], excel replace sum(log) eqkeep(N mean sd) keep($yvars female $xvars)
outreg2 using "$reproduce_files\Table 1B HarvestValue.xls" if e(sample)==1 & female==0 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)
outreg2 using "$reproduce_files\Table 1B HarvestValue.xls" if e(sample)==1 & female==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)


/*constrained - 15-29 year olds*/
reg $yvars female $xvars if age15_29==1 [aw=hhweight], vce(robust)

/*exporting summary statistics*/
outreg2 using "$reproduce_files\Table 1B HarvestValue.xls" if e(sample)==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars female $xvars)
outreg2 using "$reproduce_files\Table 1B HarvestValue.xls" if e(sample)==1 & female==0 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)
outreg2 using "$reproduce_files\Table 1B HarvestValue.xls" if e(sample)==1 & female==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)


/*constrained - 30-64 year olds*/
reg $yvars female $xvars if age30_64==1 [aw=hhweight], vce(robust)

/*exporting summary statistics*/
outreg2 using "$reproduce_files\Table 1B HarvestValue.xls" if e(sample)==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars female $xvars)
outreg2 using "$reproduce_files\Table 1B HarvestValue.xls" if e(sample)==1 & female==0 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)
outreg2 using "$reproduce_files\Table 1B HarvestValue.xls" if e(sample)==1 & female==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)




/*running oaxaca-blinder decomposition*/
oaxaca $yvars $xvars [aw=hhweight], by(female) relax pooled vce(robust)
outreg2 using "$reproduce_files\Table 6.xls", excel se dec(3) replace  ctitle(All)

oaxaca $yvars $xvars if age15_29==1 [aw=hhweight], by(female) relax pooled vce(robust)
outreg2 using "$reproduce_files\Appendix Table 8.xls", excel se dec(3) replace ctitle(age 15-29)

oaxaca $yvars $xvars if age30_64==1 [aw=hhweight], by(female) relax pooled vce(robust)
outreg2 using "$reproduce_files\Appendix Table 8.xls", excel se dec(3) append ctitle(age 30-64)



/*using amount sold as a measure of productivity*/
global yvars "asinhsold"
global xvars "age age2 adults child0_5 financial_account married divorced secondary_completed vehicle equipment area area_sq land_distance export_crop manager_owner manager_control male_hh_totaldays female_hh_totaldays total_days_men total_days_women all_harvest_sold fertilizer_use pestfungherb_use" 


/*constrained - all*/
reg $yvars female $xvars [aw=hhweight], vce(robust)

/*exporting summary statistics*/
outreg2 using "$reproduce_files\Table 1B CropSales.xls" if e(sample)==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars female $xvars)
outreg2 using "$reproduce_files\Table 1B CropSales.xls" if e(sample)==1 & female==0 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)
outreg2 using "$reproduce_files\Table 1B CropSales.xls" if e(sample)==1 & female==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)

/*constrained - 15-29 year olds*/
reg $yvars female $xvars if age15_29==1 [aw=hhweight], vce(robust)

/*exporting summary statistics*/
outreg2 using "$reproduce_files\Table 1B CropSales.xls" if e(sample)==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars female $xvars)
outreg2 using "$reproduce_files\Table 1B CropSales.xls" if e(sample)==1 & female==0 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)
outreg2 using "$reproduce_files\Table 1B CropSales.xls" if e(sample)==1 & female==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)

/*constrained - 30-64 year olds*/
reg $yvars female $xvars if age30_64==1 [aw=hhweight], vce(robust)

/*exporting summary statistics*/
outreg2 using "$reproduce_files\Table 1B CropSales.xls" if e(sample)==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars female $xvars)
outreg2 using "$reproduce_files\Table 1B CropSales.xls" if e(sample)==1 & female==0 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)
outreg2 using "$reproduce_files\Table 1B CropSales.xls" if e(sample)==1 & female==1 [aw=hhweight], excel append sum(log) eqkeep(N mean sd) keep($yvars $xvars)




/*running oaxaca-blinder decomposition*/
oaxaca $yvars $xvars [aw=hhweight], by(female) relax pooled vce(robust)
outreg2 using "$reproduce_files\Table 6.xls", excel se dec(3) append ctitle(All)

oaxaca $yvars $xvars if age15_29==1 [aw=hhweight], by(female) relax pooled vce(robust)
outreg2 using "$reproduce_files\Appendix Table 9.xls", excel se dec(3) replace ctitle(age 15-29)

oaxaca $yvars $xvars if age30_64==1 [aw=hhweight], by(female) relax pooled vce(robust)
outreg2 using "$reproduce_files\Appendix Table 9.xls", excel se dec(3) append ctitle(age 30-64)


